# coding: utf-8

"""
    Seeq REST API

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: 66.119.1-v202603241138-CD
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from __future__ import annotations

from typing import Any, Dict, List, Optional, Set

from ..api_client import ApiClient
from ..configuration import Configuration
from ..models import *

class TreesApi(object):
    api_client: ApiClient

    def __init__(self, api_client: Optional[ApiClient] = None) -> None: ...

    def batch_move_nodes_to_parents(
        self,
        **kwargs: Any,
    ) -> ItemBatchOutputV1: ...

    def batch_move_nodes_to_parents_with_http_info(
        self,
        **kwargs: Any,
    ) -> Any: ...

    def create_tree(
        self,
        **kwargs: Any,
    ) -> AssetGroupOutputV1: ...

    def create_tree_with_http_info(
        self,
        **kwargs: Any,
    ) -> Any: ...

    def get_all_tree_types(
        self,
        **kwargs: Any,
    ) -> ItemPreviewListV1: ...

    def get_all_tree_types_with_http_info(
        self,
        **kwargs: Any,
    ) -> Any: ...

    def get_tree(
        self,
        **kwargs: Any,
    ) -> AssetTreeOutputV1: ...

    def get_tree_with_http_info(
        self,
        **kwargs: Any,
    ) -> Any: ...

    def get_tree_root_nodes(
        self,
        **kwargs: Any,
    ) -> AssetTreeOutputV1: ...

    def get_tree_root_nodes_with_http_info(
        self,
        **kwargs: Any,
    ) -> Any: ...

    def move_nodes_to_parent(
        self,
        **kwargs: Any,
    ) -> StatusMessageBase: ...

    def move_nodes_to_parent_with_http_info(
        self,
        **kwargs: Any,
    ) -> Any: ...

    def move_nodes_to_root_of_tree(
        self,
        **kwargs: Any,
    ) -> StatusMessageBase: ...

    def move_nodes_to_root_of_tree_with_http_info(
        self,
        **kwargs: Any,
    ) -> Any: ...

    def rebuild_search_index(
        self,
        **kwargs: Any,
    ) -> None: ...

    def rebuild_search_index_with_http_info(
        self,
        **kwargs: Any,
    ) -> Any: ...

    def remove_node_from_tree(
        self,
        **kwargs: Any,
    ) -> StatusMessageBase: ...

    def remove_node_from_tree_with_http_info(
        self,
        **kwargs: Any,
    ) -> Any: ...

    def scale_across_tree(
        self,
        **kwargs: Any,
    ) -> ScaleAcrossTreeOutputV1: ...

    def scale_across_tree_with_http_info(
        self,
        **kwargs: Any,
    ) -> Any: ...

    def treemap(
        self,
        **kwargs: Any,
    ) -> TreemapOutputV1: ...

    def treemap_with_http_info(
        self,
        **kwargs: Any,
    ) -> Any: ...

    def update_tree(
        self,
        **kwargs: Any,
    ) -> AssetGroupOutputV1: ...

    def update_tree_with_http_info(
        self,
        **kwargs: Any,
    ) -> Any: ...



# coding: utf-8

"""
    Seeq REST API

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: 66.119.1-v202603241138-CD
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from __future__ import annotations

from typing import Any, ClassVar, Dict, List, Optional, Set, TYPE_CHECKING

if TYPE_CHECKING:
    from . import *  # noqa: F401,F403


class ThresholdOutputV1(object):
    swagger_types: ClassVar[Dict[str, str]] = ...
    attribute_map: ClassVar[Dict[str, str]] = ...

    _is_generated: Optional[bool]
    _item: Optional[ItemPreviewV1]
    _priority: Optional[PriorityV1]
    _value: Optional[ScalarValueOutputV1]


    def __init__(
        self,
        is_generated: Optional[bool] = None,
        item: Optional[ItemPreviewV1] = None,
        priority: Optional[PriorityV1] = None,
        value: Optional[ScalarValueOutputV1] = None,
    ) -> None: ...

    @property
    def is_generated(self) -> Optional[bool]: ...

    @is_generated.setter
    def is_generated(self, is_generated: Optional[bool]) -> None: ...

    @property
    def item(self) -> Optional[ItemPreviewV1]: ...

    @item.setter
    def item(self, item: Optional[ItemPreviewV1]) -> None: ...

    @property
    def priority(self) -> Optional[PriorityV1]: ...

    @priority.setter
    def priority(self, priority: Optional[PriorityV1]) -> None: ...

    @property
    def value(self) -> Optional[ScalarValueOutputV1]: ...

    @value.setter
    def value(self, value: Optional[ScalarValueOutputV1]) -> None: ...

    def to_dict(self) -> Dict[str, Any]: ...
    def to_str(self) -> str: ...
    def __repr__(self) -> str: ...
    def __eq__(self, other: object) -> bool: ...
    def __ne__(self, other: object) -> bool: ...



# coding: utf-8

"""
    Seeq REST API

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: 66.119.1-v202603241138-CD
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from __future__ import annotations

from typing import Any, ClassVar, Dict, List, Optional, Set, TYPE_CHECKING

if TYPE_CHECKING:
    from . import *  # noqa: F401,F403


class SchedulableAdminOutputV1(object):
    swagger_types: ClassVar[Dict[str, str]] = ...
    attribute_map: ClassVar[Dict[str, str]] = ...

    _average_run_time: int
    _content_count: int
    _document_id: Optional[str]
    _id: str
    _is_notification_configured: Optional[bool]
    _last_run_time: Optional[str]
    _last_updated: str
    _last_viewed_at: Optional[str]
    _name: str
    _next_run_time: Optional[str]
    _owner: Optional[str]
    _schedulable_type: str
    _schedules: Optional[List[str]]
    _status_message: Optional[str]
    _topic_id: Optional[str]
    _total_run_time: int
    _workbook: Optional[SchedulableWorkbookOutputV1]


    def __init__(
        self,
        average_run_time: Optional[int] = None,
        content_count: Optional[int] = None,
        document_id: Optional[str] = None,
        id: Optional[str] = None,
        is_notification_configured: Optional[bool] = None,
        last_run_time: Optional[str] = None,
        last_updated: Optional[str] = None,
        last_viewed_at: Optional[str] = None,
        name: Optional[str] = None,
        next_run_time: Optional[str] = None,
        owner: Optional[str] = None,
        schedulable_type: Optional[str] = None,
        schedules: Optional[List[str]] = None,
        status_message: Optional[str] = None,
        topic_id: Optional[str] = None,
        total_run_time: Optional[int] = None,
        workbook: Optional[SchedulableWorkbookOutputV1] = None,
    ) -> None: ...

    @property
    def average_run_time(self) -> int: ...

    @average_run_time.setter
    def average_run_time(self, average_run_time: int) -> None: ...

    @property
    def content_count(self) -> int: ...

    @content_count.setter
    def content_count(self, content_count: int) -> None: ...

    @property
    def document_id(self) -> Optional[str]: ...

    @document_id.setter
    def document_id(self, document_id: Optional[str]) -> None: ...

    @property
    def id(self) -> str: ...

    @id.setter
    def id(self, id: str) -> None: ...

    @property
    def is_notification_configured(self) -> Optional[bool]: ...

    @is_notification_configured.setter
    def is_notification_configured(self, is_notification_configured: Optional[bool]) -> None: ...

    @property
    def last_run_time(self) -> Optional[str]: ...

    @last_run_time.setter
    def last_run_time(self, last_run_time: Optional[str]) -> None: ...

    @property
    def last_updated(self) -> str: ...

    @last_updated.setter
    def last_updated(self, last_updated: str) -> None: ...

    @property
    def last_viewed_at(self) -> Optional[str]: ...

    @last_viewed_at.setter
    def last_viewed_at(self, last_viewed_at: Optional[str]) -> None: ...

    @property
    def name(self) -> str: ...

    @name.setter
    def name(self, name: str) -> None: ...

    @property
    def next_run_time(self) -> Optional[str]: ...

    @next_run_time.setter
    def next_run_time(self, next_run_time: Optional[str]) -> None: ...

    @property
    def owner(self) -> Optional[str]: ...

    @owner.setter
    def owner(self, owner: Optional[str]) -> None: ...

    @property
    def schedulable_type(self) -> str: ...

    @schedulable_type.setter
    def schedulable_type(self, schedulable_type: str) -> None: ...

    @property
    def schedules(self) -> Optional[List[str]]: ...

    @schedules.setter
    def schedules(self, schedules: Optional[List[str]]) -> None: ...

    @property
    def status_message(self) -> Optional[str]: ...

    @status_message.setter
    def status_message(self, status_message: Optional[str]) -> None: ...

    @property
    def topic_id(self) -> Optional[str]: ...

    @topic_id.setter
    def topic_id(self, topic_id: Optional[str]) -> None: ...

    @property
    def total_run_time(self) -> int: ...

    @total_run_time.setter
    def total_run_time(self, total_run_time: int) -> None: ...

    @property
    def workbook(self) -> Optional[SchedulableWorkbookOutputV1]: ...

    @workbook.setter
    def workbook(self, workbook: Optional[SchedulableWorkbookOutputV1]) -> None: ...

    def to_dict(self) -> Dict[str, Any]: ...
    def to_str(self) -> str: ...
    def __repr__(self) -> str: ...
    def __eq__(self, other: object) -> bool: ...
    def __ne__(self, other: object) -> bool: ...



# coding: utf-8

"""
    Seeq REST API

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: 66.119.1-v202603241138-CD
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from __future__ import annotations

from typing import Any, ClassVar, Dict, List, Optional, Set, TYPE_CHECKING

if TYPE_CHECKING:
    from . import *  # noqa: F401,F403


class SendEmailInputV1(object):
    swagger_types: ClassVar[Dict[str, str]] = ...
    attribute_map: ClassVar[Dict[str, str]] = ...

    _to_emails: List[SendEmailContactV1]
    _cc_emails: List[SendEmailContactV1]
    _bcc_emails: List[SendEmailContactV1]
    _subject: str
    _content: str
    _attachments: List[SendEmailAttachmentV1]
    _reply_to: Optional[List[SendEmailContactV1]]


    def __init__(
        self,
        to_emails: Optional[List[SendEmailContactV1]] = None,
        cc_emails: Optional[List[SendEmailContactV1]] = None,
        bcc_emails: Optional[List[SendEmailContactV1]] = None,
        subject: Optional[str] = None,
        content: Optional[str] = None,
        attachments: Optional[List[SendEmailAttachmentV1]] = None,
        reply_to: Optional[List[SendEmailContactV1]] = None,
    ) -> None: ...

    @property
    def to_emails(self) -> List[SendEmailContactV1]: ...

    @to_emails.setter
    def to_emails(self, to_emails: List[SendEmailContactV1]) -> None: ...

    @property
    def cc_emails(self) -> List[SendEmailContactV1]: ...

    @cc_emails.setter
    def cc_emails(self, cc_emails: List[SendEmailContactV1]) -> None: ...

    @property
    def bcc_emails(self) -> List[SendEmailContactV1]: ...

    @bcc_emails.setter
    def bcc_emails(self, bcc_emails: List[SendEmailContactV1]) -> None: ...

    @property
    def subject(self) -> str: ...

    @subject.setter
    def subject(self, subject: str) -> None: ...

    @property
    def content(self) -> str: ...

    @content.setter
    def content(self, content: str) -> None: ...

    @property
    def attachments(self) -> List[SendEmailAttachmentV1]: ...

    @attachments.setter
    def attachments(self, attachments: List[SendEmailAttachmentV1]) -> None: ...

    @property
    def reply_to(self) -> Optional[List[SendEmailContactV1]]: ...

    @reply_to.setter
    def reply_to(self, reply_to: Optional[List[SendEmailContactV1]]) -> None: ...

    def to_dict(self) -> Dict[str, Any]: ...
    def to_str(self) -> str: ...
    def __repr__(self) -> str: ...
    def __eq__(self, other: object) -> bool: ...
    def __ne__(self, other: object) -> bool: ...



# coding: utf-8

"""
    Seeq REST API

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: 66.119.1-v202603241138-CD
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from __future__ import annotations

from typing import Any, ClassVar, Dict, List, Optional, Set, TYPE_CHECKING

if TYPE_CHECKING:
    from . import *  # noqa: F401,F403


class SamplesOverwriteInputV1(object):
    swagger_types: ClassVar[Dict[str, str]] = ...
    attribute_map: ClassVar[Dict[str, str]] = ...

    _interval: Optional[IntervalV1]
    _samples: List[SampleInputV1]


    def __init__(
        self,
        interval: Optional[IntervalV1] = None,
        samples: Optional[List[SampleInputV1]] = None,
    ) -> None: ...

    @property
    def interval(self) -> Optional[IntervalV1]: ...

    @interval.setter
    def interval(self, interval: Optional[IntervalV1]) -> None: ...

    @property
    def samples(self) -> List[SampleInputV1]: ...

    @samples.setter
    def samples(self, samples: List[SampleInputV1]) -> None: ...

    def to_dict(self) -> Dict[str, Any]: ...
    def to_str(self) -> str: ...
    def __repr__(self) -> str: ...
    def __eq__(self, other: object) -> bool: ...
    def __ne__(self, other: object) -> bool: ...



# coding: utf-8

"""
    Seeq REST API

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: 66.119.1-v202603241138-CD
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from pprint import pformat
from six import iteritems
import re


class CalculatedTableOutputV1(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """


    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'archived': 'bool',
        'column_dependencies': 'list[CalculatedTableColumnDependencyOutputV1]',
        'column_metadata': 'list[CalculatedTableColumnMetadataOutputV1]',
        'created_at': 'str',
        'creator_id': 'str',
        'description': 'str',
        'id': 'str',
        'locked': 'bool',
        'name': 'str',
        'owner_id': 'str',
        'query': 'str',
        'scoped_to': 'str',
        'updated_at': 'str'
    }

    attribute_map = {
        'archived': 'archived',
        'column_dependencies': 'columnDependencies',
        'column_metadata': 'columnMetadata',
        'created_at': 'createdAt',
        'creator_id': 'creatorId',
        'description': 'description',
        'id': 'id',
        'locked': 'locked',
        'name': 'name',
        'owner_id': 'ownerId',
        'query': 'query',
        'scoped_to': 'scopedTo',
        'updated_at': 'updatedAt'
    }

    def __init__(self, archived=None, column_dependencies=None, column_metadata=None, created_at=None, creator_id=None, description=None, id=None, locked=None, name=None, owner_id=None, query=None, scoped_to=None, updated_at=None):
        """
        CalculatedTableOutputV1 - a model defined in Swagger
        """

        self._archived = None
        self._column_dependencies = None
        self._column_metadata = None
        self._created_at = None
        self._creator_id = None
        self._description = None
        self._id = None
        self._locked = None
        self._name = None
        self._owner_id = None
        self._query = None
        self._scoped_to = None
        self._updated_at = None

        if archived is not None:
          self.archived = archived
        if column_dependencies is not None:
          self.column_dependencies = column_dependencies
        if column_metadata is not None:
          self.column_metadata = column_metadata
        if created_at is not None:
          self.created_at = created_at
        if creator_id is not None:
          self.creator_id = creator_id
        if description is not None:
          self.description = description
        if id is not None:
          self.id = id
        if locked is not None:
          self.locked = locked
        if name is not None:
          self.name = name
        if owner_id is not None:
          self.owner_id = owner_id
        if query is not None:
          self.query = query
        if scoped_to is not None:
          self.scoped_to = scoped_to
        if updated_at is not None:
          self.updated_at = updated_at

    @property
    def archived(self):
        """
        Gets the archived of this CalculatedTableOutputV1.
        Whether the calculated table is archived

        :return: The archived of this CalculatedTableOutputV1.
        :rtype: bool
        """
        return self._archived

    @archived.setter
    def archived(self, archived):
        """
        Sets the archived of this CalculatedTableOutputV1.
        Whether the calculated table is archived

        :param archived: The archived of this CalculatedTableOutputV1.
        :type: bool
        """

        self._archived = archived

    @property
    def column_dependencies(self):
        """
        Gets the column_dependencies of this CalculatedTableOutputV1.
        Dependencies declared for the columns returned by the query

        :return: The column_dependencies of this CalculatedTableOutputV1.
        :rtype: list[CalculatedTableColumnDependencyOutputV1]
        """
        return self._column_dependencies

    @column_dependencies.setter
    def column_dependencies(self, column_dependencies):
        """
        Sets the column_dependencies of this CalculatedTableOutputV1.
        Dependencies declared for the columns returned by the query

        :param column_dependencies: The column_dependencies of this CalculatedTableOutputV1.
        :type: list[CalculatedTableColumnDependencyOutputV1]
        """

        self._column_dependencies = column_dependencies

    @property
    def column_metadata(self):
        """
        Gets the column_metadata of this CalculatedTableOutputV1.
        Metadata describing the columns returned by the query

        :return: The column_metadata of this CalculatedTableOutputV1.
        :rtype: list[CalculatedTableColumnMetadataOutputV1]
        """
        return self._column_metadata

    @column_metadata.setter
    def column_metadata(self, column_metadata):
        """
        Sets the column_metadata of this CalculatedTableOutputV1.
        Metadata describing the columns returned by the query

        :param column_metadata: The column_metadata of this CalculatedTableOutputV1.
        :type: list[CalculatedTableColumnMetadataOutputV1]
        """

        self._column_metadata = column_metadata

    @property
    def created_at(self):
        """
        Gets the created_at of this CalculatedTableOutputV1.
        Timestamp the calculated table was created

        :return: The created_at of this CalculatedTableOutputV1.
        :rtype: str
        """
        return self._created_at

    @created_at.setter
    def created_at(self, created_at):
        """
        Sets the created_at of this CalculatedTableOutputV1.
        Timestamp the calculated table was created

        :param created_at: The created_at of this CalculatedTableOutputV1.
        :type: str
        """

        self._created_at = created_at

    @property
    def creator_id(self):
        """
        Gets the creator_id of this CalculatedTableOutputV1.
        ID of the creator

        :return: The creator_id of this CalculatedTableOutputV1.
        :rtype: str
        """
        return self._creator_id

    @creator_id.setter
    def creator_id(self, creator_id):
        """
        Sets the creator_id of this CalculatedTableOutputV1.
        ID of the creator

        :param creator_id: The creator_id of this CalculatedTableOutputV1.
        :type: str
        """

        self._creator_id = creator_id

    @property
    def description(self):
        """
        Gets the description of this CalculatedTableOutputV1.
        Description for the calculated table

        :return: The description of this CalculatedTableOutputV1.
        :rtype: str
        """
        return self._description

    @description.setter
    def description(self, description):
        """
        Sets the description of this CalculatedTableOutputV1.
        Description for the calculated table

        :param description: The description of this CalculatedTableOutputV1.
        :type: str
        """

        self._description = description

    @property
    def id(self):
        """
        Gets the id of this CalculatedTableOutputV1.
        ID of the calculated table

        :return: The id of this CalculatedTableOutputV1.
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """
        Sets the id of this CalculatedTableOutputV1.
        ID of the calculated table

        :param id: The id of this CalculatedTableOutputV1.
        :type: str
        """

        self._id = id

    @property
    def locked(self):
        """
        Gets the locked of this CalculatedTableOutputV1.
        Whether the calculated table is locked

        :return: The locked of this CalculatedTableOutputV1.
        :rtype: bool
        """
        return self._locked

    @locked.setter
    def locked(self, locked):
        """
        Sets the locked of this CalculatedTableOutputV1.
        Whether the calculated table is locked

        :param locked: The locked of this CalculatedTableOutputV1.
        :type: bool
        """

        self._locked = locked

    @property
    def name(self):
        """
        Gets the name of this CalculatedTableOutputV1.
        Name of the calculated table

        :return: The name of this CalculatedTableOutputV1.
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """
        Sets the name of this CalculatedTableOutputV1.
        Name of the calculated table

        :param name: The name of this CalculatedTableOutputV1.
        :type: str
        """

        self._name = name

    @property
    def owner_id(self):
        """
        Gets the owner_id of this CalculatedTableOutputV1.
        ID of the owner

        :return: The owner_id of this CalculatedTableOutputV1.
        :rtype: str
        """
        return self._owner_id

    @owner_id.setter
    def owner_id(self, owner_id):
        """
        Sets the owner_id of this CalculatedTableOutputV1.
        ID of the owner

        :param owner_id: The owner_id of this CalculatedTableOutputV1.
        :type: str
        """

        self._owner_id = owner_id

    @property
    def query(self):
        """
        Gets the query of this CalculatedTableOutputV1.
        The SQL query

        :return: The query of this CalculatedTableOutputV1.
        :rtype: str
        """
        return self._query

    @query.setter
    def query(self, query):
        """
        Sets the query of this CalculatedTableOutputV1.
        The SQL query

        :param query: The query of this CalculatedTableOutputV1.
        :type: str
        """

        self._query = query

    @property
    def scoped_to(self):
        """
        Gets the scoped_to of this CalculatedTableOutputV1.
        Insights Board that this calculated table is scoped to, or null for global

        :return: The scoped_to of this CalculatedTableOutputV1.
        :rtype: str
        """
        return self._scoped_to

    @scoped_to.setter
    def scoped_to(self, scoped_to):
        """
        Sets the scoped_to of this CalculatedTableOutputV1.
        Insights Board that this calculated table is scoped to, or null for global

        :param scoped_to: The scoped_to of this CalculatedTableOutputV1.
        :type: str
        """

        self._scoped_to = scoped_to

    @property
    def updated_at(self):
        """
        Gets the updated_at of this CalculatedTableOutputV1.
        Timestamp the calculated table was last updated

        :return: The updated_at of this CalculatedTableOutputV1.
        :rtype: str
        """
        return self._updated_at

    @updated_at.setter
    def updated_at(self, updated_at):
        """
        Sets the updated_at of this CalculatedTableOutputV1.
        Timestamp the calculated table was last updated

        :param updated_at: The updated_at of this CalculatedTableOutputV1.
        :type: str
        """

        self._updated_at = updated_at

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        if not isinstance(other, CalculatedTableOutputV1):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other



# coding: utf-8

"""
    Seeq REST API

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: 66.119.1-v202603241138-CD
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from pprint import pformat
from six import iteritems
import re


class TileLayoutOutputV1(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """


    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'height': 'int',
        'id': 'str',
        'width': 'int',
        'x': 'int',
        'y': 'int'
    }

    attribute_map = {
        'height': 'height',
        'id': 'id',
        'width': 'width',
        'x': 'x',
        'y': 'y'
    }

    def __init__(self, height=None, id=None, width=None, x=None, y=None):
        """
        TileLayoutOutputV1 - a model defined in Swagger
        """

        self._height = None
        self._id = None
        self._width = None
        self._x = None
        self._y = None

        if height is not None:
          self.height = height
        if id is not None:
          self.id = id
        if width is not None:
          self.width = width
        if x is not None:
          self.x = x
        if y is not None:
          self.y = y

    @property
    def height(self):
        """
        Gets the height of this TileLayoutOutputV1.
        The height of the tile in grid units

        :return: The height of this TileLayoutOutputV1.
        :rtype: int
        """
        return self._height

    @height.setter
    def height(self, height):
        """
        Sets the height of this TileLayoutOutputV1.
        The height of the tile in grid units

        :param height: The height of this TileLayoutOutputV1.
        :type: int
        """
        if height is None:
            raise ValueError("Invalid value for `height`, must not be `None`")

        self._height = height

    @property
    def id(self):
        """
        Gets the id of this TileLayoutOutputV1.
        The unique identifier of the tile

        :return: The id of this TileLayoutOutputV1.
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """
        Sets the id of this TileLayoutOutputV1.
        The unique identifier of the tile

        :param id: The id of this TileLayoutOutputV1.
        :type: str
        """
        if id is None:
            raise ValueError("Invalid value for `id`, must not be `None`")

        self._id = id

    @property
    def width(self):
        """
        Gets the width of this TileLayoutOutputV1.
        The width of the tile in grid units

        :return: The width of this TileLayoutOutputV1.
        :rtype: int
        """
        return self._width

    @width.setter
    def width(self, width):
        """
        Sets the width of this TileLayoutOutputV1.
        The width of the tile in grid units

        :param width: The width of this TileLayoutOutputV1.
        :type: int
        """
        if width is None:
            raise ValueError("Invalid value for `width`, must not be `None`")

        self._width = width

    @property
    def x(self):
        """
        Gets the x of this TileLayoutOutputV1.
        The X position of the tile in the grid

        :return: The x of this TileLayoutOutputV1.
        :rtype: int
        """
        return self._x

    @x.setter
    def x(self, x):
        """
        Sets the x of this TileLayoutOutputV1.
        The X position of the tile in the grid

        :param x: The x of this TileLayoutOutputV1.
        :type: int
        """
        if x is None:
            raise ValueError("Invalid value for `x`, must not be `None`")

        self._x = x

    @property
    def y(self):
        """
        Gets the y of this TileLayoutOutputV1.
        The Y position of the tile in the grid

        :return: The y of this TileLayoutOutputV1.
        :rtype: int
        """
        return self._y

    @y.setter
    def y(self, y):
        """
        Sets the y of this TileLayoutOutputV1.
        The Y position of the tile in the grid

        :param y: The y of this TileLayoutOutputV1.
        :type: int
        """
        if y is None:
            raise ValueError("Invalid value for `y`, must not be `None`")

        self._y = y

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        if not isinstance(other, TileLayoutOutputV1):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other



# coding: utf-8

"""
    Seeq REST API

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: 66.119.1-v202603241138-CD
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from __future__ import annotations

from typing import Any, ClassVar, Dict, List, Optional, Set, TYPE_CHECKING

if TYPE_CHECKING:
    from . import *  # noqa: F401,F403


class RegressionOutputV1(object):
    swagger_types: ClassVar[Dict[str, str]] = ...
    attribute_map: ClassVar[Dict[str, str]] = ...

    _adjusted_r_squared: float
    _error_sum_squares: float
    _intercept: float
    _intercept_standard_error: float
    _is_uncertain: bool
    _r_squared: Optional[float]
    _regression_sum_squares: float
    _suggested_p_value_cutoff: float


    def __init__(
        self,
        adjusted_r_squared: Optional[float] = None,
        error_sum_squares: Optional[float] = None,
        intercept: Optional[float] = None,
        intercept_standard_error: Optional[float] = None,
        is_uncertain: Optional[bool] = False,
        r_squared: Optional[float] = None,
        regression_sum_squares: Optional[float] = None,
        suggested_p_value_cutoff: Optional[float] = None,
    ) -> None: ...

    @property
    def adjusted_r_squared(self) -> float: ...

    @adjusted_r_squared.setter
    def adjusted_r_squared(self, adjusted_r_squared: float) -> None: ...

    @property
    def error_sum_squares(self) -> float: ...

    @error_sum_squares.setter
    def error_sum_squares(self, error_sum_squares: float) -> None: ...

    @property
    def intercept(self) -> float: ...

    @intercept.setter
    def intercept(self, intercept: float) -> None: ...

    @property
    def intercept_standard_error(self) -> float: ...

    @intercept_standard_error.setter
    def intercept_standard_error(self, intercept_standard_error: float) -> None: ...

    @property
    def is_uncertain(self) -> bool: ...

    @is_uncertain.setter
    def is_uncertain(self, is_uncertain: bool) -> None: ...

    @property
    def r_squared(self) -> Optional[float]: ...

    @r_squared.setter
    def r_squared(self, r_squared: Optional[float]) -> None: ...

    @property
    def regression_sum_squares(self) -> float: ...

    @regression_sum_squares.setter
    def regression_sum_squares(self, regression_sum_squares: float) -> None: ...

    @property
    def suggested_p_value_cutoff(self) -> float: ...

    @suggested_p_value_cutoff.setter
    def suggested_p_value_cutoff(self, suggested_p_value_cutoff: float) -> None: ...

    def to_dict(self) -> Dict[str, Any]: ...
    def to_str(self) -> str: ...
    def __repr__(self) -> str: ...
    def __eq__(self, other: object) -> bool: ...
    def __ne__(self, other: object) -> bool: ...



# coding: utf-8

"""
    Seeq REST API

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: 66.119.1-v202603241138-CD
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from __future__ import annotations

from typing import Any, ClassVar, Dict, List, Optional, Set, TYPE_CHECKING

if TYPE_CHECKING:
    from . import *  # noqa: F401,F403


class PrecachedItemOutputV1(object):
    swagger_types: ClassVar[Dict[str, str]] = ...
    attribute_map: ClassVar[Dict[str, str]] = ...

    _cache_id: Optional[str]
    _capsule_property_infos: Optional[List[PreCachedConditionCapsulePropertyInfoV1]]
    _data_id: Optional[str]
    _last_certain_key_nanos: Optional[int]
    _max_duration_nanos: Optional[int]
    _max_interpolation_nanos: Optional[int]
    _type: Optional[str]
    _uncertainty_override_nanos: Optional[int]
    _value_uom: Optional[str]


    def __init__(
        self,
        cache_id: Optional[str] = None,
        capsule_property_infos: Optional[List[PreCachedConditionCapsulePropertyInfoV1]] = None,
        data_id: Optional[str] = None,
        last_certain_key_nanos: Optional[int] = None,
        max_duration_nanos: Optional[int] = None,
        max_interpolation_nanos: Optional[int] = None,
        type: Optional[str] = None,
        uncertainty_override_nanos: Optional[int] = None,
        value_uom: Optional[str] = None,
    ) -> None: ...

    @property
    def cache_id(self) -> Optional[str]: ...

    @cache_id.setter
    def cache_id(self, cache_id: Optional[str]) -> None: ...

    @property
    def capsule_property_infos(self) -> Optional[List[PreCachedConditionCapsulePropertyInfoV1]]: ...

    @capsule_property_infos.setter
    def capsule_property_infos(self, capsule_property_infos: Optional[List[PreCachedConditionCapsulePropertyInfoV1]]) -> None: ...

    @property
    def data_id(self) -> Optional[str]: ...

    @data_id.setter
    def data_id(self, data_id: Optional[str]) -> None: ...

    @property
    def last_certain_key_nanos(self) -> Optional[int]: ...

    @last_certain_key_nanos.setter
    def last_certain_key_nanos(self, last_certain_key_nanos: Optional[int]) -> None: ...

    @property
    def max_duration_nanos(self) -> Optional[int]: ...

    @max_duration_nanos.setter
    def max_duration_nanos(self, max_duration_nanos: Optional[int]) -> None: ...

    @property
    def max_interpolation_nanos(self) -> Optional[int]: ...

    @max_interpolation_nanos.setter
    def max_interpolation_nanos(self, max_interpolation_nanos: Optional[int]) -> None: ...

    @property
    def type(self) -> Optional[str]: ...

    @type.setter
    def type(self, type: Optional[str]) -> None: ...

    @property
    def uncertainty_override_nanos(self) -> Optional[int]: ...

    @uncertainty_override_nanos.setter
    def uncertainty_override_nanos(self, uncertainty_override_nanos: Optional[int]) -> None: ...

    @property
    def value_uom(self) -> Optional[str]: ...

    @value_uom.setter
    def value_uom(self, value_uom: Optional[str]) -> None: ...

    def to_dict(self) -> Dict[str, Any]: ...
    def to_str(self) -> str: ...
    def __repr__(self) -> str: ...
    def __eq__(self, other: object) -> bool: ...
    def __ne__(self, other: object) -> bool: ...



# coding: utf-8

"""
    Seeq REST API

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: 66.119.1-v202603241138-CD
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from __future__ import annotations

from typing import Any, ClassVar, Dict, List, Optional, Set, TYPE_CHECKING

if TYPE_CHECKING:
    from . import *  # noqa: F401,F403


class ContextCommentInputV1(object):
    swagger_types: ClassVar[Dict[str, str]] = ...
    attribute_map: ClassVar[Dict[str, str]] = ...

    _category_id: Optional[str]
    _comment: Optional[str]
    _datum_id: Optional[str]
    _end_time: Optional[str]
    _is_pinned: Optional[bool]
    _mentions: Optional[List[MentionInputV1]]
    _source: Optional[ContextSourceInputV1]
    _start_time: Optional[str]
    _table_id: Optional[str]


    def __init__(
        self,
        category_id: Optional[str] = None,
        comment: Optional[str] = None,
        datum_id: Optional[str] = None,
        end_time: Optional[str] = None,
        is_pinned: Optional[bool] = None,
        mentions: Optional[List[MentionInputV1]] = None,
        source: Optional[ContextSourceInputV1] = None,
        start_time: Optional[str] = None,
        table_id: Optional[str] = None,
    ) -> None: ...

    @property
    def category_id(self) -> Optional[str]: ...

    @category_id.setter
    def category_id(self, category_id: Optional[str]) -> None: ...

    @property
    def comment(self) -> Optional[str]: ...

    @comment.setter
    def comment(self, comment: Optional[str]) -> None: ...

    @property
    def datum_id(self) -> Optional[str]: ...

    @datum_id.setter
    def datum_id(self, datum_id: Optional[str]) -> None: ...

    @property
    def end_time(self) -> Optional[str]: ...

    @end_time.setter
    def end_time(self, end_time: Optional[str]) -> None: ...

    @property
    def is_pinned(self) -> Optional[bool]: ...

    @is_pinned.setter
    def is_pinned(self, is_pinned: Optional[bool]) -> None: ...

    @property
    def mentions(self) -> Optional[List[MentionInputV1]]: ...

    @mentions.setter
    def mentions(self, mentions: Optional[List[MentionInputV1]]) -> None: ...

    @property
    def source(self) -> Optional[ContextSourceInputV1]: ...

    @source.setter
    def source(self, source: Optional[ContextSourceInputV1]) -> None: ...

    @property
    def start_time(self) -> Optional[str]: ...

    @start_time.setter
    def start_time(self, start_time: Optional[str]) -> None: ...

    @property
    def table_id(self) -> Optional[str]: ...

    @table_id.setter
    def table_id(self, table_id: Optional[str]) -> None: ...

    def to_dict(self) -> Dict[str, Any]: ...
    def to_str(self) -> str: ...
    def __repr__(self) -> str: ...
    def __eq__(self, other: object) -> bool: ...
    def __ne__(self, other: object) -> bool: ...



# coding: utf-8

"""
    Seeq REST API

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: 66.119.1-v202603241138-CD
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from __future__ import annotations

from typing import Any, ClassVar, Dict, List, Optional, Set, TYPE_CHECKING

if TYPE_CHECKING:
    from . import *  # noqa: F401,F403


class TimeInterval(object):
    swagger_types: ClassVar[Dict[str, str]] = ...
    attribute_map: ClassVar[Dict[str, str]] = ...

    _duration_time: Optional[int]
    _empty: Optional[bool]
    _end_string: Optional[str]
    _end_time: Optional[int]
    _limit: Optional[bool]
    _start_string: Optional[str]
    _start_time: Optional[int]
    _time_key: Optional[int]


    def __init__(
        self,
        duration_time: Optional[int] = None,
        empty: Optional[bool] = None,
        end_string: Optional[str] = None,
        end_time: Optional[int] = None,
        limit: Optional[bool] = None,
        start_string: Optional[str] = None,
        start_time: Optional[int] = None,
        time_key: Optional[int] = None,
    ) -> None: ...

    @property
    def duration_time(self) -> Optional[int]: ...

    @duration_time.setter
    def duration_time(self, duration_time: Optional[int]) -> None: ...

    @property
    def empty(self) -> Optional[bool]: ...

    @empty.setter
    def empty(self, empty: Optional[bool]) -> None: ...

    @property
    def end_string(self) -> Optional[str]: ...

    @end_string.setter
    def end_string(self, end_string: Optional[str]) -> None: ...

    @property
    def end_time(self) -> Optional[int]: ...

    @end_time.setter
    def end_time(self, end_time: Optional[int]) -> None: ...

    @property
    def limit(self) -> Optional[bool]: ...

    @limit.setter
    def limit(self, limit: Optional[bool]) -> None: ...

    @property
    def start_string(self) -> Optional[str]: ...

    @start_string.setter
    def start_string(self, start_string: Optional[str]) -> None: ...

    @property
    def start_time(self) -> Optional[int]: ...

    @start_time.setter
    def start_time(self, start_time: Optional[int]) -> None: ...

    @property
    def time_key(self) -> Optional[int]: ...

    @time_key.setter
    def time_key(self, time_key: Optional[int]) -> None: ...

    def to_dict(self) -> Dict[str, Any]: ...
    def to_str(self) -> str: ...
    def __repr__(self) -> str: ...
    def __eq__(self, other: object) -> bool: ...
    def __ne__(self, other: object) -> bool: ...



# coding: utf-8

"""
    Seeq REST API

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: 66.119.1-v202603241138-CD
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from __future__ import annotations

from typing import Any, ClassVar, Dict, List, Optional, Set, TYPE_CHECKING

if TYPE_CHECKING:
    from . import *  # noqa: F401,F403


class ReleaseNotesOutputV1(object):
    swagger_types: ClassVar[Dict[str, str]] = ...
    attribute_map: ClassVar[Dict[str, str]] = ...

    _current_release_notes: List[IssueSummaryOutputV1]
    _next_upgrade_time: Optional[str]
    _next_version: Optional[str]
    _past_release_notes: List[IssueSummaryOutputV1]
    _upcoming_release_notes: List[IssueSummaryOutputV1]


    def __init__(
        self,
        current_release_notes: Optional[List[IssueSummaryOutputV1]] = None,
        next_upgrade_time: Optional[str] = None,
        next_version: Optional[str] = None,
        past_release_notes: Optional[List[IssueSummaryOutputV1]] = None,
        upcoming_release_notes: Optional[List[IssueSummaryOutputV1]] = None,
    ) -> None: ...

    @property
    def current_release_notes(self) -> List[IssueSummaryOutputV1]: ...

    @current_release_notes.setter
    def current_release_notes(self, current_release_notes: List[IssueSummaryOutputV1]) -> None: ...

    @property
    def next_upgrade_time(self) -> Optional[str]: ...

    @next_upgrade_time.setter
    def next_upgrade_time(self, next_upgrade_time: Optional[str]) -> None: ...

    @property
    def next_version(self) -> Optional[str]: ...

    @next_version.setter
    def next_version(self, next_version: Optional[str]) -> None: ...

    @property
    def past_release_notes(self) -> List[IssueSummaryOutputV1]: ...

    @past_release_notes.setter
    def past_release_notes(self, past_release_notes: List[IssueSummaryOutputV1]) -> None: ...

    @property
    def upcoming_release_notes(self) -> List[IssueSummaryOutputV1]: ...

    @upcoming_release_notes.setter
    def upcoming_release_notes(self, upcoming_release_notes: List[IssueSummaryOutputV1]) -> None: ...

    def to_dict(self) -> Dict[str, Any]: ...
    def to_str(self) -> str: ...
    def __repr__(self) -> str: ...
    def __eq__(self, other: object) -> bool: ...
    def __ne__(self, other: object) -> bool: ...



# coding: utf-8

"""
    Seeq REST API

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: 66.119.1-v202603241138-CD
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from __future__ import annotations

from typing import Any, ClassVar, Dict, List, Optional, Set, TYPE_CHECKING

if TYPE_CHECKING:
    from . import *  # noqa: F401,F403


class PreProvisionInputV1(object):
    swagger_types: ClassVar[Dict[str, str]] = ...
    attribute_map: ClassVar[Dict[str, str]] = ...

    _agent_name: Optional[str]
    _machine_name: str
    _re_provisioning_allowed: Optional[bool]
    _source_address: Optional[str]


    def __init__(
        self,
        agent_name: Optional[str] = None,
        machine_name: Optional[str] = None,
        re_provisioning_allowed: Optional[bool] = False,
        source_address: Optional[str] = None,
    ) -> None: ...

    @property
    def agent_name(self) -> Optional[str]: ...

    @agent_name.setter
    def agent_name(self, agent_name: Optional[str]) -> None: ...

    @property
    def machine_name(self) -> str: ...

    @machine_name.setter
    def machine_name(self, machine_name: str) -> None: ...

    @property
    def re_provisioning_allowed(self) -> Optional[bool]: ...

    @re_provisioning_allowed.setter
    def re_provisioning_allowed(self, re_provisioning_allowed: Optional[bool]) -> None: ...

    @property
    def source_address(self) -> Optional[str]: ...

    @source_address.setter
    def source_address(self, source_address: Optional[str]) -> None: ...

    def to_dict(self) -> Dict[str, Any]: ...
    def to_str(self) -> str: ...
    def __repr__(self) -> str: ...
    def __eq__(self, other: object) -> bool: ...
    def __ne__(self, other: object) -> bool: ...



# coding: utf-8

"""
    Seeq REST API

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: 66.119.1-v202603241138-CD
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from pprint import pformat
from six import iteritems
import re


class CalculatedTableDataQueryInputV1(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """


    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'filter': 'Filter',
        'limit': 'int',
        'timezone': 'str'
    }

    attribute_map = {
        'filter': 'filter',
        'limit': 'limit',
        'timezone': 'timezone'
    }

    def __init__(self, filter=None, limit=None, timezone=None):
        """
        CalculatedTableDataQueryInputV1 - a model defined in Swagger
        """

        self._filter = None
        self._limit = None
        self._timezone = None

        if filter is not None:
          self.filter = filter
        if limit is not None:
          self.limit = limit
        if timezone is not None:
          self.timezone = timezone

    @property
    def filter(self):
        """
        Gets the filter of this CalculatedTableDataQueryInputV1.

        :return: The filter of this CalculatedTableDataQueryInputV1.
        :rtype: Filter
        """
        return self._filter

    @filter.setter
    def filter(self, filter):
        """
        Sets the filter of this CalculatedTableDataQueryInputV1.

        :param filter: The filter of this CalculatedTableDataQueryInputV1.
        :type: Filter
        """

        self._filter = filter

    @property
    def limit(self):
        """
        Gets the limit of this CalculatedTableDataQueryInputV1.
        Maximum number of rows to return

        :return: The limit of this CalculatedTableDataQueryInputV1.
        :rtype: int
        """
        return self._limit

    @limit.setter
    def limit(self, limit):
        """
        Sets the limit of this CalculatedTableDataQueryInputV1.
        Maximum number of rows to return

        :param limit: The limit of this CalculatedTableDataQueryInputV1.
        :type: int
        """

        self._limit = limit

    @property
    def timezone(self):
        """
        Gets the timezone of this CalculatedTableDataQueryInputV1.
        Timezone to use for timestamp operations (e.g. 'America/New_York')

        :return: The timezone of this CalculatedTableDataQueryInputV1.
        :rtype: str
        """
        return self._timezone

    @timezone.setter
    def timezone(self, timezone):
        """
        Sets the timezone of this CalculatedTableDataQueryInputV1.
        Timezone to use for timestamp operations (e.g. 'America/New_York')

        :param timezone: The timezone of this CalculatedTableDataQueryInputV1.
        :type: str
        """
        if timezone is None:
            raise ValueError("Invalid value for `timezone`, must not be `None`")

        self._timezone = timezone

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        if not isinstance(other, CalculatedTableDataQueryInputV1):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other



# coding: utf-8

"""
    Seeq REST API

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: 66.119.1-v202603241138-CD
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from __future__ import annotations

from typing import Any, ClassVar, Dict, List, Optional, Set, TYPE_CHECKING

if TYPE_CHECKING:
    from . import *  # noqa: F401,F403


class InstanceOutputV1(object):
    swagger_types: ClassVar[Dict[str, str]] = ...
    attribute_map: ClassVar[Dict[str, str]] = ...

    _errors: Optional[List[ModelApplicationErrorOutputV1]]
    _input_features: Optional[List[InputFeatureV1]]
    _inputs: Optional[List[ModelApplicationMappingV1]]
    _instance_id: Optional[str]
    _is_retired: Optional[bool]
    _model_container_id: Optional[str]
    _model_id: Optional[str]
    _outputs: Optional[List[InstanceOutputMappingV1]]
    _table_application_id: Optional[str]


    def __init__(
        self,
        errors: Optional[List[ModelApplicationErrorOutputV1]] = None,
        input_features: Optional[List[InputFeatureV1]] = None,
        inputs: Optional[List[ModelApplicationMappingV1]] = None,
        instance_id: Optional[str] = None,
        is_retired: Optional[bool] = None,
        model_container_id: Optional[str] = None,
        model_id: Optional[str] = None,
        outputs: Optional[List[InstanceOutputMappingV1]] = None,
        table_application_id: Optional[str] = None,
    ) -> None: ...

    @property
    def errors(self) -> Optional[List[ModelApplicationErrorOutputV1]]: ...

    @errors.setter
    def errors(self, errors: Optional[List[ModelApplicationErrorOutputV1]]) -> None: ...

    @property
    def input_features(self) -> Optional[List[InputFeatureV1]]: ...

    @input_features.setter
    def input_features(self, input_features: Optional[List[InputFeatureV1]]) -> None: ...

    @property
    def inputs(self) -> Optional[List[ModelApplicationMappingV1]]: ...

    @inputs.setter
    def inputs(self, inputs: Optional[List[ModelApplicationMappingV1]]) -> None: ...

    @property
    def instance_id(self) -> Optional[str]: ...

    @instance_id.setter
    def instance_id(self, instance_id: Optional[str]) -> None: ...

    @property
    def is_retired(self) -> Optional[bool]: ...

    @is_retired.setter
    def is_retired(self, is_retired: Optional[bool]) -> None: ...

    @property
    def model_container_id(self) -> Optional[str]: ...

    @model_container_id.setter
    def model_container_id(self, model_container_id: Optional[str]) -> None: ...

    @property
    def model_id(self) -> Optional[str]: ...

    @model_id.setter
    def model_id(self, model_id: Optional[str]) -> None: ...

    @property
    def outputs(self) -> Optional[List[InstanceOutputMappingV1]]: ...

    @outputs.setter
    def outputs(self, outputs: Optional[List[InstanceOutputMappingV1]]) -> None: ...

    @property
    def table_application_id(self) -> Optional[str]: ...

    @table_application_id.setter
    def table_application_id(self, table_application_id: Optional[str]) -> None: ...

    def to_dict(self) -> Dict[str, Any]: ...
    def to_str(self) -> str: ...
    def __repr__(self) -> str: ...
    def __eq__(self, other: object) -> bool: ...
    def __ne__(self, other: object) -> bool: ...



# coding: utf-8

"""
    Seeq REST API

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: 66.119.1-v202603241138-CD
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from __future__ import annotations

from typing import Any, Dict, List, Optional, Set

from ..api_client import ApiClient
from ..configuration import Configuration
from ..models import *

class ModelsApi(object):
    api_client: ApiClient

    def __init__(self, api_client: Optional[ApiClient] = None) -> None: ...

    def apply_model(
        self,
        **kwargs: Any,
    ) -> InstanceOutputV1: ...

    def apply_model_with_http_info(
        self,
        **kwargs: Any,
    ) -> Any: ...

    def apply_model_to_table(
        self,
        **kwargs: Any,
    ) -> ModelTableApplicationOutputV1: ...

    def apply_model_to_table_with_http_info(
        self,
        **kwargs: Any,
    ) -> Any: ...

    def archive_model(
        self,
        **kwargs: Any,
    ) -> ArchiveOutputV1: ...

    def archive_model_with_http_info(
        self,
        **kwargs: Any,
    ) -> Any: ...

    def create_draft(
        self,
        **kwargs: Any,
    ) -> ModelOutputV1: ...

    def create_draft_with_http_info(
        self,
        **kwargs: Any,
    ) -> Any: ...

    def create_model(
        self,
        **kwargs: Any,
    ) -> ModelOutputV1: ...

    def create_model_with_http_info(
        self,
        **kwargs: Any,
    ) -> Any: ...

    def create_model_from_items(
        self,
        **kwargs: Any,
    ) -> ModelOutputV1: ...

    def create_model_from_items_with_http_info(
        self,
        **kwargs: Any,
    ) -> Any: ...

    def create_model_from_table_column_definitions(
        self,
        **kwargs: Any,
    ) -> ModelOutputV1: ...

    def create_model_from_table_column_definitions_with_http_info(
        self,
        **kwargs: Any,
    ) -> Any: ...

    def duplicate_model(
        self,
        **kwargs: Any,
    ) -> ModelOutputV1: ...

    def duplicate_model_with_http_info(
        self,
        **kwargs: Any,
    ) -> Any: ...

    def edit_model(
        self,
        **kwargs: Any,
    ) -> ModelOutputV1: ...

    def edit_model_with_http_info(
        self,
        **kwargs: Any,
    ) -> Any: ...

    def generate_column_model(
        self,
        **kwargs: Any,
    ) -> ColumnModelOutput: ...

    def generate_column_model_with_http_info(
        self,
        **kwargs: Any,
    ) -> Any: ...

    def get_applied_model_tables(
        self,
        **kwargs: Any,
    ) -> List[TableDefinitionOutputV1]: ...

    def get_applied_model_tables_with_http_info(
        self,
        **kwargs: Any,
    ) -> Any: ...

    def get_instance(
        self,
        **kwargs: Any,
    ) -> InstanceOutputV1: ...

    def get_instance_with_http_info(
        self,
        **kwargs: Any,
    ) -> Any: ...

    def get_instances_for_model(
        self,
        **kwargs: Any,
    ) -> InstanceOutputPaginatedListV1: ...

    def get_instances_for_model_with_http_info(
        self,
        **kwargs: Any,
    ) -> Any: ...

    def get_instances_for_table(
        self,
        **kwargs: Any,
    ) -> InstanceOutputPaginatedListV1: ...

    def get_instances_for_table_with_http_info(
        self,
        **kwargs: Any,
    ) -> Any: ...

    def get_model(
        self,
        **kwargs: Any,
    ) -> ModelOutputV1: ...

    def get_model_with_http_info(
        self,
        **kwargs: Any,
    ) -> Any: ...

    def get_models(
        self,
        **kwargs: Any,
    ) -> ModelOutputListV1: ...

    def get_models_with_http_info(
        self,
        **kwargs: Any,
    ) -> Any: ...

    def get_table_definition_model_applications(
        self,
        **kwargs: Any,
    ) -> ModelTableApplicationsOutputListV1: ...

    def get_table_definition_model_applications_with_http_info(
        self,
        **kwargs: Any,
    ) -> Any: ...

    def publish_model_version(
        self,
        **kwargs: Any,
    ) -> StatusMessageBase: ...

    def publish_model_version_with_http_info(
        self,
        **kwargs: Any,
    ) -> Any: ...

    def reapply_model(
        self,
        **kwargs: Any,
    ) -> InstanceOutputV1: ...

    def reapply_model_with_http_info(
        self,
        **kwargs: Any,
    ) -> Any: ...

    def reapply_model_to_table(
        self,
        **kwargs: Any,
    ) -> ModelTableApplicationOutputV1: ...

    def reapply_model_to_table_with_http_info(
        self,
        **kwargs: Any,
    ) -> Any: ...

    def retire_application(
        self,
        **kwargs: Any,
    ) -> TableApplicationRetiredOutputV1: ...

    def retire_application_with_http_info(
        self,
        **kwargs: Any,
    ) -> Any: ...

    def retire_instance(
        self,
        **kwargs: Any,
    ) -> InstanceRetiredOutputV1: ...

    def retire_instance_with_http_info(
        self,
        **kwargs: Any,
    ) -> Any: ...



# coding: utf-8

"""
    Seeq REST API

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: 66.119.1-v202603241138-CD
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from __future__ import annotations

from typing import Any, ClassVar, Dict, List, Optional, Set, TYPE_CHECKING

if TYPE_CHECKING:
    from . import *  # noqa: F401,F403


class TableModelApplicationInputV1(object):
    swagger_types: ClassVar[Dict[str, str]] = ...
    attribute_map: ClassVar[Dict[str, str]] = ...

    _derived_column_names: List[ModelDerivedColumnNamesInputV1]
    _inputs: Optional[List[ModelApplicationMappingV1]]


    def __init__(
        self,
        derived_column_names: Optional[List[ModelDerivedColumnNamesInputV1]] = None,
        inputs: Optional[List[ModelApplicationMappingV1]] = None,
    ) -> None: ...

    @property
    def derived_column_names(self) -> List[ModelDerivedColumnNamesInputV1]: ...

    @derived_column_names.setter
    def derived_column_names(self, derived_column_names: List[ModelDerivedColumnNamesInputV1]) -> None: ...

    @property
    def inputs(self) -> Optional[List[ModelApplicationMappingV1]]: ...

    @inputs.setter
    def inputs(self, inputs: Optional[List[ModelApplicationMappingV1]]) -> None: ...

    def to_dict(self) -> Dict[str, Any]: ...
    def to_str(self) -> str: ...
    def __repr__(self) -> str: ...
    def __eq__(self, other: object) -> bool: ...
    def __ne__(self, other: object) -> bool: ...



# coding: utf-8

"""
    Seeq REST API

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: 66.119.1-v202603241138-CD
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from pprint import pformat
from six import iteritems
import re


class ModelFromIdsInputV1(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """


    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'description': 'str',
        'name': 'str',
        'referenced_input_items': 'list[ReferencedInputItemV1]',
        'referenced_output_items': 'list[ReferencedOutputItemV1]',
        'scoped_to': 'str',
        'table_definition_guid': 'str'
    }

    attribute_map = {
        'description': 'description',
        'name': 'name',
        'referenced_input_items': 'referencedInputItems',
        'referenced_output_items': 'referencedOutputItems',
        'scoped_to': 'scopedTo',
        'table_definition_guid': 'tableDefinitionGuid'
    }

    def __init__(self, description=None, name=None, referenced_input_items=None, referenced_output_items=None, scoped_to=None, table_definition_guid=None):
        """
        ModelFromIdsInputV1 - a model defined in Swagger
        """

        self._description = None
        self._name = None
        self._referenced_input_items = None
        self._referenced_output_items = None
        self._scoped_to = None
        self._table_definition_guid = None

        if description is not None:
          self.description = description
        if name is not None:
          self.name = name
        if referenced_input_items is not None:
          self.referenced_input_items = referenced_input_items
        if referenced_output_items is not None:
          self.referenced_output_items = referenced_output_items
        if scoped_to is not None:
          self.scoped_to = scoped_to
        if table_definition_guid is not None:
          self.table_definition_guid = table_definition_guid

    @property
    def description(self):
        """
        Gets the description of this ModelFromIdsInputV1.
        Description of the model

        :return: The description of this ModelFromIdsInputV1.
        :rtype: str
        """
        return self._description

    @description.setter
    def description(self, description):
        """
        Sets the description of this ModelFromIdsInputV1.
        Description of the model

        :param description: The description of this ModelFromIdsInputV1.
        :type: str
        """

        self._description = description

    @property
    def name(self):
        """
        Gets the name of this ModelFromIdsInputV1.
        Name of the model

        :return: The name of this ModelFromIdsInputV1.
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """
        Sets the name of this ModelFromIdsInputV1.
        Name of the model

        :param name: The name of this ModelFromIdsInputV1.
        :type: str
        """
        if name is None:
            raise ValueError("Invalid value for `name`, must not be `None`")

        self._name = name

    @property
    def referenced_input_items(self):
        """
        Gets the referenced_input_items of this ModelFromIdsInputV1.
        List of inputs IDs to be used for reference to create the model. May be an item GUID or a column definition ID

        :return: The referenced_input_items of this ModelFromIdsInputV1.
        :rtype: list[ReferencedInputItemV1]
        """
        return self._referenced_input_items

    @referenced_input_items.setter
    def referenced_input_items(self, referenced_input_items):
        """
        Sets the referenced_input_items of this ModelFromIdsInputV1.
        List of inputs IDs to be used for reference to create the model. May be an item GUID or a column definition ID

        :param referenced_input_items: The referenced_input_items of this ModelFromIdsInputV1.
        :type: list[ReferencedInputItemV1]
        """
        if referenced_input_items is None:
            raise ValueError("Invalid value for `referenced_input_items`, must not be `None`")

        self._referenced_input_items = referenced_input_items

    @property
    def referenced_output_items(self):
        """
        Gets the referenced_output_items of this ModelFromIdsInputV1.
        List of output IDs to be used for reference to create the model. May be an item GUID or a column definition ID

        :return: The referenced_output_items of this ModelFromIdsInputV1.
        :rtype: list[ReferencedOutputItemV1]
        """
        return self._referenced_output_items

    @referenced_output_items.setter
    def referenced_output_items(self, referenced_output_items):
        """
        Sets the referenced_output_items of this ModelFromIdsInputV1.
        List of output IDs to be used for reference to create the model. May be an item GUID or a column definition ID

        :param referenced_output_items: The referenced_output_items of this ModelFromIdsInputV1.
        :type: list[ReferencedOutputItemV1]
        """
        if referenced_output_items is None:
            raise ValueError("Invalid value for `referenced_output_items`, must not be `None`")

        self._referenced_output_items = referenced_output_items

    @property
    def scoped_to(self):
        """
        Gets the scoped_to of this ModelFromIdsInputV1.
        The ID of the workbook to which the model will be scoped. If not provided, the model will have a global scope

        :return: The scoped_to of this ModelFromIdsInputV1.
        :rtype: str
        """
        return self._scoped_to

    @scoped_to.setter
    def scoped_to(self, scoped_to):
        """
        Sets the scoped_to of this ModelFromIdsInputV1.
        The ID of the workbook to which the model will be scoped. If not provided, the model will have a global scope

        :param scoped_to: The scoped_to of this ModelFromIdsInputV1.
        :type: str
        """

        self._scoped_to = scoped_to

    @property
    def table_definition_guid(self):
        """
        Gets the table_definition_guid of this ModelFromIdsInputV1.
        Table Definition GUID

        :return: The table_definition_guid of this ModelFromIdsInputV1.
        :rtype: str
        """
        return self._table_definition_guid

    @table_definition_guid.setter
    def table_definition_guid(self, table_definition_guid):
        """
        Sets the table_definition_guid of this ModelFromIdsInputV1.
        Table Definition GUID

        :param table_definition_guid: The table_definition_guid of this ModelFromIdsInputV1.
        :type: str
        """

        self._table_definition_guid = table_definition_guid

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        if not isinstance(other, ModelFromIdsInputV1):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other



# coding: utf-8

"""
    Seeq REST API

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: 66.119.1-v202603241138-CD
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from __future__ import annotations

from typing import Any, ClassVar, Dict, List, Optional, Set, TYPE_CHECKING

if TYPE_CHECKING:
    from . import *  # noqa: F401,F403


class ContentOutputV1(object):
    swagger_types: ClassVar[Dict[str, str]] = ...
    attribute_map: ClassVar[Dict[str, str]] = ...

    _analysis_view_type: Optional[str]
    _asset_selection: Optional[AssetSelectionOutputV1]
    _date_range: Optional[DateRangeOutputV1]
    _description: Optional[str]
    _effective_permissions: Optional[PermissionsV1]
    _fill_to_fit: bool
    _hash_code: Optional[str]
    _height: Optional[int]
    _hide_uncertainty: bool
    _id: str
    _is_archived: Optional[bool]
    _is_redacted: Optional[bool]
    _name: str
    _react: bool
    _report: Optional[ItemPreviewV1]
    _scale: Optional[float]
    _selector: Optional[str]
    _source_workbook: Optional[str]
    _source_worksheet: Optional[str]
    _source_workstep: Optional[str]
    _status_message: Optional[str]
    _summary_type: Optional[str]
    _summary_value: Optional[str]
    _timezone: Optional[str]
    _translation_key: Optional[str]
    _type: str
    _warning: Optional[str]
    _width: Optional[int]


    def __init__(
        self,
        analysis_view_type: Optional[str] = None,
        asset_selection: Optional[AssetSelectionOutputV1] = None,
        date_range: Optional[DateRangeOutputV1] = None,
        description: Optional[str] = None,
        effective_permissions: Optional[PermissionsV1] = None,
        fill_to_fit: Optional[bool] = None,
        hash_code: Optional[str] = None,
        height: Optional[int] = None,
        hide_uncertainty: Optional[bool] = None,
        id: Optional[str] = None,
        is_archived: Optional[bool] = False,
        is_redacted: Optional[bool] = False,
        name: Optional[str] = None,
        react: Optional[bool] = None,
        report: Optional[ItemPreviewV1] = None,
        scale: Optional[float] = None,
        selector: Optional[str] = None,
        source_workbook: Optional[str] = None,
        source_worksheet: Optional[str] = None,
        source_workstep: Optional[str] = None,
        status_message: Optional[str] = None,
        summary_type: Optional[str] = None,
        summary_value: Optional[str] = None,
        timezone: Optional[str] = None,
        translation_key: Optional[str] = None,
        type: Optional[str] = None,
        warning: Optional[str] = None,
        width: Optional[int] = None,
    ) -> None: ...

    @property
    def analysis_view_type(self) -> Optional[str]: ...

    @analysis_view_type.setter
    def analysis_view_type(self, analysis_view_type: Optional[str]) -> None: ...

    @property
    def asset_selection(self) -> Optional[AssetSelectionOutputV1]: ...

    @asset_selection.setter
    def asset_selection(self, asset_selection: Optional[AssetSelectionOutputV1]) -> None: ...

    @property
    def date_range(self) -> Optional[DateRangeOutputV1]: ...

    @date_range.setter
    def date_range(self, date_range: Optional[DateRangeOutputV1]) -> None: ...

    @property
    def description(self) -> Optional[str]: ...

    @description.setter
    def description(self, description: Optional[str]) -> None: ...

    @property
    def effective_permissions(self) -> Optional[PermissionsV1]: ...

    @effective_permissions.setter
    def effective_permissions(self, effective_permissions: Optional[PermissionsV1]) -> None: ...

    @property
    def fill_to_fit(self) -> bool: ...

    @fill_to_fit.setter
    def fill_to_fit(self, fill_to_fit: bool) -> None: ...

    @property
    def hash_code(self) -> Optional[str]: ...

    @hash_code.setter
    def hash_code(self, hash_code: Optional[str]) -> None: ...

    @property
    def height(self) -> Optional[int]: ...

    @height.setter
    def height(self, height: Optional[int]) -> None: ...

    @property
    def hide_uncertainty(self) -> bool: ...

    @hide_uncertainty.setter
    def hide_uncertainty(self, hide_uncertainty: bool) -> None: ...

    @property
    def id(self) -> str: ...

    @id.setter
    def id(self, id: str) -> None: ...

    @property
    def is_archived(self) -> Optional[bool]: ...

    @is_archived.setter
    def is_archived(self, is_archived: Optional[bool]) -> None: ...

    @property
    def is_redacted(self) -> Optional[bool]: ...

    @is_redacted.setter
    def is_redacted(self, is_redacted: Optional[bool]) -> None: ...

    @property
    def name(self) -> str: ...

    @name.setter
    def name(self, name: str) -> None: ...

    @property
    def react(self) -> bool: ...

    @react.setter
    def react(self, react: bool) -> None: ...

    @property
    def report(self) -> Optional[ItemPreviewV1]: ...

    @report.setter
    def report(self, report: Optional[ItemPreviewV1]) -> None: ...

    @property
    def scale(self) -> Optional[float]: ...

    @scale.setter
    def scale(self, scale: Optional[float]) -> None: ...

    @property
    def selector(self) -> Optional[str]: ...

    @selector.setter
    def selector(self, selector: Optional[str]) -> None: ...

    @property
    def source_workbook(self) -> Optional[str]: ...

    @source_workbook.setter
    def source_workbook(self, source_workbook: Optional[str]) -> None: ...

    @property
    def source_worksheet(self) -> Optional[str]: ...

    @source_worksheet.setter
    def source_worksheet(self, source_worksheet: Optional[str]) -> None: ...

    @property
    def source_workstep(self) -> Optional[str]: ...

    @source_workstep.setter
    def source_workstep(self, source_workstep: Optional[str]) -> None: ...

    @property
    def status_message(self) -> Optional[str]: ...

    @status_message.setter
    def status_message(self, status_message: Optional[str]) -> None: ...

    @property
    def summary_type(self) -> Optional[str]: ...

    @summary_type.setter
    def summary_type(self, summary_type: Optional[str]) -> None: ...

    @property
    def summary_value(self) -> Optional[str]: ...

    @summary_value.setter
    def summary_value(self, summary_value: Optional[str]) -> None: ...

    @property
    def timezone(self) -> Optional[str]: ...

    @timezone.setter
    def timezone(self, timezone: Optional[str]) -> None: ...

    @property
    def translation_key(self) -> Optional[str]: ...

    @translation_key.setter
    def translation_key(self, translation_key: Optional[str]) -> None: ...

    @property
    def type(self) -> str: ...

    @type.setter
    def type(self, type: str) -> None: ...

    @property
    def warning(self) -> Optional[str]: ...

    @warning.setter
    def warning(self, warning: Optional[str]) -> None: ...

    @property
    def width(self) -> Optional[int]: ...

    @width.setter
    def width(self, width: Optional[int]) -> None: ...

    def to_dict(self) -> Dict[str, Any]: ...
    def to_str(self) -> str: ...
    def __repr__(self) -> str: ...
    def __eq__(self, other: object) -> bool: ...
    def __ne__(self, other: object) -> bool: ...



# coding: utf-8

"""
    Seeq REST API

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: 66.119.1-v202603241138-CD
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from pprint import pformat
from six import iteritems
import re


class HierarchySearchV1(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """


    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'ancestor_predicates': 'list[AncestorFilterInputV1]',
        'fixed_list_predicates': 'list[FixedListFilterInputV1]',
        'hierarchy_id': 'str',
        'is_include': 'bool',
        'level': 'int',
        'predicates': 'list[PropertyFilterInputV1]',
        'search_order': 'int',
        'search_type': 'str'
    }

    attribute_map = {
        'ancestor_predicates': 'ancestorPredicates',
        'fixed_list_predicates': 'fixedListPredicates',
        'hierarchy_id': 'hierarchyId',
        'is_include': 'isInclude',
        'level': 'level',
        'predicates': 'predicates',
        'search_order': 'searchOrder',
        'search_type': 'searchType'
    }

    def __init__(self, ancestor_predicates=None, fixed_list_predicates=None, hierarchy_id=None, is_include=None, level=None, predicates=None, search_order=None, search_type=None):
        """
        HierarchySearchV1 - a model defined in Swagger
        """

        self._ancestor_predicates = None
        self._fixed_list_predicates = None
        self._hierarchy_id = None
        self._is_include = None
        self._level = None
        self._predicates = None
        self._search_order = None
        self._search_type = None

        if ancestor_predicates is not None:
          self.ancestor_predicates = ancestor_predicates
        if fixed_list_predicates is not None:
          self.fixed_list_predicates = fixed_list_predicates
        if hierarchy_id is not None:
          self.hierarchy_id = hierarchy_id
        if is_include is not None:
          self.is_include = is_include
        if level is not None:
          self.level = level
        if predicates is not None:
          self.predicates = predicates
        if search_order is not None:
          self.search_order = search_order
        if search_type is not None:
          self.search_type = search_type

    @property
    def ancestor_predicates(self):
        """
        Gets the ancestor_predicates of this HierarchySearchV1.
        A list of ancestor predicates by which to filter the items. Can include value filters and filters using a hierarchy's source table columns to specify an ancestor. Each predicate specifies property filters for an ancestor and an optional level (1 = direct parent, 2 = grandparent, etc.).

        :return: The ancestor_predicates of this HierarchySearchV1.
        :rtype: list[AncestorFilterInputV1]
        """
        return self._ancestor_predicates

    @ancestor_predicates.setter
    def ancestor_predicates(self, ancestor_predicates):
        """
        Sets the ancestor_predicates of this HierarchySearchV1.
        A list of ancestor predicates by which to filter the items. Can include value filters and filters using a hierarchy's source table columns to specify an ancestor. Each predicate specifies property filters for an ancestor and an optional level (1 = direct parent, 2 = grandparent, etc.).

        :param ancestor_predicates: The ancestor_predicates of this HierarchySearchV1.
        :type: list[AncestorFilterInputV1]
        """

        self._ancestor_predicates = ancestor_predicates

    @property
    def fixed_list_predicates(self):
        """
        Gets the fixed_list_predicates of this HierarchySearchV1.
        A list of predicates by which to filter the items. Can include filters on item properties and filters using a hierarchy's source table column names.

        :return: The fixed_list_predicates of this HierarchySearchV1.
        :rtype: list[FixedListFilterInputV1]
        """
        return self._fixed_list_predicates

    @fixed_list_predicates.setter
    def fixed_list_predicates(self, fixed_list_predicates):
        """
        Sets the fixed_list_predicates of this HierarchySearchV1.
        A list of predicates by which to filter the items. Can include filters on item properties and filters using a hierarchy's source table column names.

        :param fixed_list_predicates: The fixed_list_predicates of this HierarchySearchV1.
        :type: list[FixedListFilterInputV1]
        """

        self._fixed_list_predicates = fixed_list_predicates

    @property
    def hierarchy_id(self):
        """
        Gets the hierarchy_id of this HierarchySearchV1.
        A hierarchy id that will be used to find nodes for hierarchy events. This search can only be used if includeHierarchy is true in the ItemFinderInputV1.

        :return: The hierarchy_id of this HierarchySearchV1.
        :rtype: str
        """
        return self._hierarchy_id

    @hierarchy_id.setter
    def hierarchy_id(self, hierarchy_id):
        """
        Sets the hierarchy_id of this HierarchySearchV1.
        A hierarchy id that will be used to find nodes for hierarchy events. This search can only be used if includeHierarchy is true in the ItemFinderInputV1.

        :param hierarchy_id: The hierarchy_id of this HierarchySearchV1.
        :type: str
        """
        if hierarchy_id is None:
            raise ValueError("Invalid value for `hierarchy_id`, must not be `None`")

        self._hierarchy_id = hierarchy_id

    @property
    def is_include(self):
        """
        Gets the is_include of this HierarchySearchV1.
        If true the items found by this configuration will be included in the output, if false then the results will be excluded from the output (even if found by another finder configuration)

        :return: The is_include of this HierarchySearchV1.
        :rtype: bool
        """
        return self._is_include

    @is_include.setter
    def is_include(self, is_include):
        """
        Sets the is_include of this HierarchySearchV1.
        If true the items found by this configuration will be included in the output, if false then the results will be excluded from the output (even if found by another finder configuration)

        :param is_include: The is_include of this HierarchySearchV1.
        :type: bool
        """
        if is_include is None:
            raise ValueError("Invalid value for `is_include`, must not be `None`")

        self._is_include = is_include

    @property
    def level(self):
        """
        Gets the level of this HierarchySearchV1.
        The level of the hierarchy use for finding hierarchy nodes.

        :return: The level of this HierarchySearchV1.
        :rtype: int
        """
        return self._level

    @level.setter
    def level(self, level):
        """
        Sets the level of this HierarchySearchV1.
        The level of the hierarchy use for finding hierarchy nodes.

        :param level: The level of this HierarchySearchV1.
        :type: int
        """

        self._level = level

    @property
    def predicates(self):
        """
        Gets the predicates of this HierarchySearchV1.
        A list of predicates by which to filter the items. Can include filters on item properties and filters using a hierarchy's source table column names.

        :return: The predicates of this HierarchySearchV1.
        :rtype: list[PropertyFilterInputV1]
        """
        return self._predicates

    @predicates.setter
    def predicates(self, predicates):
        """
        Sets the predicates of this HierarchySearchV1.
        A list of predicates by which to filter the items. Can include filters on item properties and filters using a hierarchy's source table column names.

        :param predicates: The predicates of this HierarchySearchV1.
        :type: list[PropertyFilterInputV1]
        """

        self._predicates = predicates

    @property
    def search_order(self):
        """
        Gets the search_order of this HierarchySearchV1.
        The order in which this search should be executed. When the same item appears in multiple searches, the search with the highest order value wins. If not specified, searches are ordered by their creation time (UUID).

        :return: The search_order of this HierarchySearchV1.
        :rtype: int
        """
        return self._search_order

    @search_order.setter
    def search_order(self, search_order):
        """
        Sets the search_order of this HierarchySearchV1.
        The order in which this search should be executed. When the same item appears in multiple searches, the search with the highest order value wins. If not specified, searches are ordered by their creation time (UUID).

        :param search_order: The search_order of this HierarchySearchV1.
        :type: int
        """

        self._search_order = search_order

    @property
    def search_type(self):
        """
        Gets the search_type of this HierarchySearchV1.
        The type of finder

        :return: The search_type of this HierarchySearchV1.
        :rtype: str
        """
        return self._search_type

    @search_type.setter
    def search_type(self, search_type):
        """
        Sets the search_type of this HierarchySearchV1.
        The type of finder

        :param search_type: The search_type of this HierarchySearchV1.
        :type: str
        """
        if search_type is None:
            raise ValueError("Invalid value for `search_type`, must not be `None`")

        self._search_type = search_type

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        if not isinstance(other, HierarchySearchV1):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other



# coding: utf-8

"""
    Seeq REST API

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: 66.119.1-v202603241138-CD
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from pprint import pformat
from six import iteritems
import re


class CustomAgentOutputV1(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """


    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'effective_permissions': 'PermissionsV1',
        'id': 'str',
        'meta': 'CustomAgentMetaOutputV1',
        'name': 'str',
        'owner': 'bool',
        'workflow': 'str'
    }

    attribute_map = {
        'effective_permissions': 'effectivePermissions',
        'id': 'id',
        'meta': 'meta',
        'name': 'name',
        'owner': 'owner',
        'workflow': 'workflow'
    }

    def __init__(self, effective_permissions=None, id=None, meta=None, name=None, owner=None, workflow=None):
        """
        CustomAgentOutputV1 - a model defined in Swagger
        """

        self._effective_permissions = None
        self._id = None
        self._meta = None
        self._name = None
        self._owner = None
        self._workflow = None

        if effective_permissions is not None:
          self.effective_permissions = effective_permissions
        if id is not None:
          self.id = id
        if meta is not None:
          self.meta = meta
        if name is not None:
          self.name = name
        if owner is not None:
          self.owner = owner
        if workflow is not None:
          self.workflow = workflow

    @property
    def effective_permissions(self):
        """
        Gets the effective_permissions of this CustomAgentOutputV1.

        :return: The effective_permissions of this CustomAgentOutputV1.
        :rtype: PermissionsV1
        """
        return self._effective_permissions

    @effective_permissions.setter
    def effective_permissions(self, effective_permissions):
        """
        Sets the effective_permissions of this CustomAgentOutputV1.

        :param effective_permissions: The effective_permissions of this CustomAgentOutputV1.
        :type: PermissionsV1
        """
        if effective_permissions is None:
            raise ValueError("Invalid value for `effective_permissions`, must not be `None`")

        self._effective_permissions = effective_permissions

    @property
    def id(self):
        """
        Gets the id of this CustomAgentOutputV1.
        The ID of the custom agent

        :return: The id of this CustomAgentOutputV1.
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """
        Sets the id of this CustomAgentOutputV1.
        The ID of the custom agent

        :param id: The id of this CustomAgentOutputV1.
        :type: str
        """
        if id is None:
            raise ValueError("Invalid value for `id`, must not be `None`")

        self._id = id

    @property
    def meta(self):
        """
        Gets the meta of this CustomAgentOutputV1.

        :return: The meta of this CustomAgentOutputV1.
        :rtype: CustomAgentMetaOutputV1
        """
        return self._meta

    @meta.setter
    def meta(self, meta):
        """
        Sets the meta of this CustomAgentOutputV1.

        :param meta: The meta of this CustomAgentOutputV1.
        :type: CustomAgentMetaOutputV1
        """
        if meta is None:
            raise ValueError("Invalid value for `meta`, must not be `None`")

        self._meta = meta

    @property
    def name(self):
        """
        Gets the name of this CustomAgentOutputV1.
        The name of the custom agent

        :return: The name of this CustomAgentOutputV1.
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """
        Sets the name of this CustomAgentOutputV1.
        The name of the custom agent

        :param name: The name of this CustomAgentOutputV1.
        :type: str
        """
        if name is None:
            raise ValueError("Invalid value for `name`, must not be `None`")

        self._name = name

    @property
    def owner(self):
        """
        Gets the owner of this CustomAgentOutputV1.

        :return: The owner of this CustomAgentOutputV1.
        :rtype: bool
        """
        return self._owner

    @owner.setter
    def owner(self, owner):
        """
        Sets the owner of this CustomAgentOutputV1.

        :param owner: The owner of this CustomAgentOutputV1.
        :type: bool
        """

        self._owner = owner

    @property
    def workflow(self):
        """
        Gets the workflow of this CustomAgentOutputV1.
        Opaque workflow JSON payload as a string

        :return: The workflow of this CustomAgentOutputV1.
        :rtype: str
        """
        return self._workflow

    @workflow.setter
    def workflow(self, workflow):
        """
        Sets the workflow of this CustomAgentOutputV1.
        Opaque workflow JSON payload as a string

        :param workflow: The workflow of this CustomAgentOutputV1.
        :type: str
        """
        if workflow is None:
            raise ValueError("Invalid value for `workflow`, must not be `None`")

        self._workflow = workflow

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        if not isinstance(other, CustomAgentOutputV1):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other



# coding: utf-8

"""
    Seeq REST API

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: 66.119.1-v202603241138-CD
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from __future__ import annotations

from typing import Any, ClassVar, Dict, List, Optional, Set, TYPE_CHECKING

if TYPE_CHECKING:
    from . import *  # noqa: F401,F403


class FormulaItemInputV1(object):
    swagger_types: ClassVar[Dict[str, str]] = ...
    attribute_map: ClassVar[Dict[str, str]] = ...

    _additional_properties: Optional[List[ScalarPropertyV1]]
    _binary_data: Optional[str]
    _data_id: Optional[str]
    _datasource_class: Optional[str]
    _datasource_id: Optional[str]
    _dependencies: Optional[List[FormulaDependencyInputV1]]
    _description: Optional[str]
    _formula: str
    _host_id: Optional[str]
    _id: Optional[str]
    _name: str
    _package_name: Optional[str]
    _parameters: Optional[List[FormulaParameterInputV1]]
    _scoped_to: Optional[str]
    _security_string: Optional[str]
    _source_security_string: Optional[str]
    _sync_token: Optional[str]
    _type: Optional[str]


    def __init__(
        self,
        additional_properties: Optional[List[ScalarPropertyV1]] = None,
        binary_data: Optional[str] = None,
        data_id: Optional[str] = None,
        datasource_class: Optional[str] = None,
        datasource_id: Optional[str] = None,
        dependencies: Optional[List[FormulaDependencyInputV1]] = None,
        description: Optional[str] = None,
        formula: Optional[str] = None,
        host_id: Optional[str] = None,
        id: Optional[str] = None,
        name: Optional[str] = None,
        package_name: Optional[str] = None,
        parameters: Optional[List[FormulaParameterInputV1]] = None,
        scoped_to: Optional[str] = None,
        security_string: Optional[str] = None,
        source_security_string: Optional[str] = None,
        sync_token: Optional[str] = None,
        type: Optional[str] = None,
    ) -> None: ...

    @property
    def additional_properties(self) -> Optional[List[ScalarPropertyV1]]: ...

    @additional_properties.setter
    def additional_properties(self, additional_properties: Optional[List[ScalarPropertyV1]]) -> None: ...

    @property
    def binary_data(self) -> Optional[str]: ...

    @binary_data.setter
    def binary_data(self, binary_data: Optional[str]) -> None: ...

    @property
    def data_id(self) -> Optional[str]: ...

    @data_id.setter
    def data_id(self, data_id: Optional[str]) -> None: ...

    @property
    def datasource_class(self) -> Optional[str]: ...

    @datasource_class.setter
    def datasource_class(self, datasource_class: Optional[str]) -> None: ...

    @property
    def datasource_id(self) -> Optional[str]: ...

    @datasource_id.setter
    def datasource_id(self, datasource_id: Optional[str]) -> None: ...

    @property
    def dependencies(self) -> Optional[List[FormulaDependencyInputV1]]: ...

    @dependencies.setter
    def dependencies(self, dependencies: Optional[List[FormulaDependencyInputV1]]) -> None: ...

    @property
    def description(self) -> Optional[str]: ...

    @description.setter
    def description(self, description: Optional[str]) -> None: ...

    @property
    def formula(self) -> str: ...

    @formula.setter
    def formula(self, formula: str) -> None: ...

    @property
    def host_id(self) -> Optional[str]: ...

    @host_id.setter
    def host_id(self, host_id: Optional[str]) -> None: ...

    @property
    def id(self) -> Optional[str]: ...

    @id.setter
    def id(self, id: Optional[str]) -> None: ...

    @property
    def name(self) -> str: ...

    @name.setter
    def name(self, name: str) -> None: ...

    @property
    def package_name(self) -> Optional[str]: ...

    @package_name.setter
    def package_name(self, package_name: Optional[str]) -> None: ...

    @property
    def parameters(self) -> Optional[List[FormulaParameterInputV1]]: ...

    @parameters.setter
    def parameters(self, parameters: Optional[List[FormulaParameterInputV1]]) -> None: ...

    @property
    def scoped_to(self) -> Optional[str]: ...

    @scoped_to.setter
    def scoped_to(self, scoped_to: Optional[str]) -> None: ...

    @property
    def security_string(self) -> Optional[str]: ...

    @security_string.setter
    def security_string(self, security_string: Optional[str]) -> None: ...

    @property
    def source_security_string(self) -> Optional[str]: ...

    @source_security_string.setter
    def source_security_string(self, source_security_string: Optional[str]) -> None: ...

    @property
    def sync_token(self) -> Optional[str]: ...

    @sync_token.setter
    def sync_token(self, sync_token: Optional[str]) -> None: ...

    @property
    def type(self) -> Optional[str]: ...

    @type.setter
    def type(self, type: Optional[str]) -> None: ...

    def to_dict(self) -> Dict[str, Any]: ...
    def to_str(self) -> str: ...
    def __repr__(self) -> str: ...
    def __eq__(self, other: object) -> bool: ...
    def __ne__(self, other: object) -> bool: ...



# coding: utf-8

"""
    Seeq REST API

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: 66.119.1-v202603241138-CD
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from pprint import pformat
from six import iteritems
import re


class PrecachedItemOutputV1(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """


    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'cache_id': 'str',
        'capsule_property_infos': 'list[PreCachedConditionCapsulePropertyInfoV1]',
        'data_id': 'str',
        'last_certain_key_nanos': 'int',
        'max_duration_nanos': 'int',
        'max_interpolation_nanos': 'int',
        'type': 'str',
        'uncertainty_override_nanos': 'int',
        'value_uom': 'str'
    }

    attribute_map = {
        'cache_id': 'cacheId',
        'capsule_property_infos': 'capsulePropertyInfos',
        'data_id': 'dataId',
        'last_certain_key_nanos': 'lastCertainKeyNanos',
        'max_duration_nanos': 'maxDurationNanos',
        'max_interpolation_nanos': 'maxInterpolationNanos',
        'type': 'type',
        'uncertainty_override_nanos': 'uncertaintyOverrideNanos',
        'value_uom': 'valueUom'
    }

    def __init__(self, cache_id=None, capsule_property_infos=None, data_id=None, last_certain_key_nanos=None, max_duration_nanos=None, max_interpolation_nanos=None, type=None, uncertainty_override_nanos=None, value_uom=None):
        """
        PrecachedItemOutputV1 - a model defined in Swagger
        """

        self._cache_id = None
        self._capsule_property_infos = None
        self._data_id = None
        self._last_certain_key_nanos = None
        self._max_duration_nanos = None
        self._max_interpolation_nanos = None
        self._type = None
        self._uncertainty_override_nanos = None
        self._value_uom = None

        if cache_id is not None:
          self.cache_id = cache_id
        if capsule_property_infos is not None:
          self.capsule_property_infos = capsule_property_infos
        if data_id is not None:
          self.data_id = data_id
        if last_certain_key_nanos is not None:
          self.last_certain_key_nanos = last_certain_key_nanos
        if max_duration_nanos is not None:
          self.max_duration_nanos = max_duration_nanos
        if max_interpolation_nanos is not None:
          self.max_interpolation_nanos = max_interpolation_nanos
        if type is not None:
          self.type = type
        if uncertainty_override_nanos is not None:
          self.uncertainty_override_nanos = uncertainty_override_nanos
        if value_uom is not None:
          self.value_uom = value_uom

    @property
    def cache_id(self):
        """
        Gets the cache_id of this PrecachedItemOutputV1.
        The cache ID of the pre-cached item. This is provided so that agents can pass it along to the datasource proxy so that it can evaluate the staleness of pre-cached data updates.

        :return: The cache_id of this PrecachedItemOutputV1.
        :rtype: str
        """
        return self._cache_id

    @cache_id.setter
    def cache_id(self, cache_id):
        """
        Sets the cache_id of this PrecachedItemOutputV1.
        The cache ID of the pre-cached item. This is provided so that agents can pass it along to the datasource proxy so that it can evaluate the staleness of pre-cached data updates.

        :param cache_id: The cache_id of this PrecachedItemOutputV1.
        :type: str
        """

        self._cache_id = cache_id

    @property
    def capsule_property_infos(self):
        """
        Gets the capsule_property_infos of this PrecachedItemOutputV1.
        If type is \"StoredCondition\" (i.e., if this object represent a pre-cached condition), this field is a list of capsule property descriptions for capsules in this condition. If type is any other value, this field is null.

        :return: The capsule_property_infos of this PrecachedItemOutputV1.
        :rtype: list[PreCachedConditionCapsulePropertyInfoV1]
        """
        return self._capsule_property_infos

    @capsule_property_infos.setter
    def capsule_property_infos(self, capsule_property_infos):
        """
        Sets the capsule_property_infos of this PrecachedItemOutputV1.
        If type is \"StoredCondition\" (i.e., if this object represent a pre-cached condition), this field is a list of capsule property descriptions for capsules in this condition. If type is any other value, this field is null.

        :param capsule_property_infos: The capsule_property_infos of this PrecachedItemOutputV1.
        :type: list[PreCachedConditionCapsulePropertyInfoV1]
        """

        self._capsule_property_infos = capsule_property_infos

    @property
    def data_id(self):
        """
        Gets the data_id of this PrecachedItemOutputV1.
        The data ID of the pre-cached item.

        :return: The data_id of this PrecachedItemOutputV1.
        :rtype: str
        """
        return self._data_id

    @data_id.setter
    def data_id(self, data_id):
        """
        Sets the data_id of this PrecachedItemOutputV1.
        The data ID of the pre-cached item.

        :param data_id: The data_id of this PrecachedItemOutputV1.
        :type: str
        """

        self._data_id = data_id

    @property
    def last_certain_key_nanos(self):
        """
        Gets the last_certain_key_nanos of this PrecachedItemOutputV1.
        The last certain key time (in nanoseconds) - if known - for the pre-cached item.

        :return: The last_certain_key_nanos of this PrecachedItemOutputV1.
        :rtype: int
        """
        return self._last_certain_key_nanos

    @last_certain_key_nanos.setter
    def last_certain_key_nanos(self, last_certain_key_nanos):
        """
        Sets the last_certain_key_nanos of this PrecachedItemOutputV1.
        The last certain key time (in nanoseconds) - if known - for the pre-cached item.

        :param last_certain_key_nanos: The last_certain_key_nanos of this PrecachedItemOutputV1.
        :type: int
        """

        self._last_certain_key_nanos = last_certain_key_nanos

    @property
    def max_duration_nanos(self):
        """
        Gets the max_duration_nanos of this PrecachedItemOutputV1.
        If type is \"StoredCondition\" (i.e., if this object represent a pre-cached condition), this field is the maximum duration of that condition in nanoseconds. If type is any other value, this field is null.

        :return: The max_duration_nanos of this PrecachedItemOutputV1.
        :rtype: int
        """
        return self._max_duration_nanos

    @max_duration_nanos.setter
    def max_duration_nanos(self, max_duration_nanos):
        """
        Sets the max_duration_nanos of this PrecachedItemOutputV1.
        If type is \"StoredCondition\" (i.e., if this object represent a pre-cached condition), this field is the maximum duration of that condition in nanoseconds. If type is any other value, this field is null.

        :param max_duration_nanos: The max_duration_nanos of this PrecachedItemOutputV1.
        :type: int
        """

        self._max_duration_nanos = max_duration_nanos

    @property
    def max_interpolation_nanos(self):
        """
        Gets the max_interpolation_nanos of this PrecachedItemOutputV1.
        If type is \"StoredSignal\" (i.e., if this object represent a pre-cached signal), this field is the maximum interpolation of that signal in nanoseconds. If type is any other value, this field is null.

        :return: The max_interpolation_nanos of this PrecachedItemOutputV1.
        :rtype: int
        """
        return self._max_interpolation_nanos

    @max_interpolation_nanos.setter
    def max_interpolation_nanos(self, max_interpolation_nanos):
        """
        Sets the max_interpolation_nanos of this PrecachedItemOutputV1.
        If type is \"StoredSignal\" (i.e., if this object represent a pre-cached signal), this field is the maximum interpolation of that signal in nanoseconds. If type is any other value, this field is null.

        :param max_interpolation_nanos: The max_interpolation_nanos of this PrecachedItemOutputV1.
        :type: int
        """

        self._max_interpolation_nanos = max_interpolation_nanos

    @property
    def type(self):
        """
        Gets the type of this PrecachedItemOutputV1.
        The type of the pre-cached item, which can be either \"StoredSignal\" for a signal or \"StoredCondition\" for a condition.

        :return: The type of this PrecachedItemOutputV1.
        :rtype: str
        """
        return self._type

    @type.setter
    def type(self, type):
        """
        Sets the type of this PrecachedItemOutputV1.
        The type of the pre-cached item, which can be either \"StoredSignal\" for a signal or \"StoredCondition\" for a condition.

        :param type: The type of this PrecachedItemOutputV1.
        :type: str
        """

        self._type = type

    @property
    def uncertainty_override_nanos(self):
        """
        Gets the uncertainty_override_nanos of this PrecachedItemOutputV1.
        The value of the \"Uncertainty Override\" property of this series or null if this property is unset.

        :return: The uncertainty_override_nanos of this PrecachedItemOutputV1.
        :rtype: int
        """
        return self._uncertainty_override_nanos

    @uncertainty_override_nanos.setter
    def uncertainty_override_nanos(self, uncertainty_override_nanos):
        """
        Sets the uncertainty_override_nanos of this PrecachedItemOutputV1.
        The value of the \"Uncertainty Override\" property of this series or null if this property is unset.

        :param uncertainty_override_nanos: The uncertainty_override_nanos of this PrecachedItemOutputV1.
        :type: int
        """

        self._uncertainty_override_nanos = uncertainty_override_nanos

    @property
    def value_uom(self):
        """
        Gets the value_uom of this PrecachedItemOutputV1.
        If type is \"StoredSignal\" (i.e., if this object represent a pre-cached signal), this field is the unit of measure for sample values. If type is any other value, this field is null.

        :return: The value_uom of this PrecachedItemOutputV1.
        :rtype: str
        """
        return self._value_uom

    @value_uom.setter
    def value_uom(self, value_uom):
        """
        Sets the value_uom of this PrecachedItemOutputV1.
        If type is \"StoredSignal\" (i.e., if this object represent a pre-cached signal), this field is the unit of measure for sample values. If type is any other value, this field is null.

        :param value_uom: The value_uom of this PrecachedItemOutputV1.
        :type: str
        """

        self._value_uom = value_uom

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        if not isinstance(other, PrecachedItemOutputV1):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other



# coding: utf-8

"""
    Seeq REST API

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: 66.119.1-v202603241138-CD
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from __future__ import annotations

from typing import Any, ClassVar, Dict, List, Optional, Set, TYPE_CHECKING

if TYPE_CHECKING:
    from . import *  # noqa: F401,F403


class UserGroupWithIdInputV1(object):
    swagger_types: ClassVar[Dict[str, str]] = ...
    attribute_map: ClassVar[Dict[str, str]] = ...

    _data_id: Optional[str]
    _datasource_class: Optional[str]
    _datasource_id: Optional[str]
    _description: Optional[str]
    _is_enabled: Optional[bool]
    _mapping: Optional[bool]
    _mappings: Optional[IdentityMappingListV1]
    _name: str
    _remote_group_editable: Optional[bool]
    _remove_permissions: Optional[bool]
    _sync_token: Optional[str]


    def __init__(
        self,
        data_id: Optional[str] = None,
        datasource_class: Optional[str] = None,
        datasource_id: Optional[str] = None,
        description: Optional[str] = None,
        is_enabled: Optional[bool] = True,
        mapping: Optional[bool] = False,
        mappings: Optional[IdentityMappingListV1] = None,
        name: Optional[str] = None,
        remote_group_editable: Optional[bool] = False,
        remove_permissions: Optional[bool] = False,
        sync_token: Optional[str] = None,
    ) -> None: ...

    @property
    def data_id(self) -> Optional[str]: ...

    @data_id.setter
    def data_id(self, data_id: Optional[str]) -> None: ...

    @property
    def datasource_class(self) -> Optional[str]: ...

    @datasource_class.setter
    def datasource_class(self, datasource_class: Optional[str]) -> None: ...

    @property
    def datasource_id(self) -> Optional[str]: ...

    @datasource_id.setter
    def datasource_id(self, datasource_id: Optional[str]) -> None: ...

    @property
    def description(self) -> Optional[str]: ...

    @description.setter
    def description(self, description: Optional[str]) -> None: ...

    @property
    def is_enabled(self) -> Optional[bool]: ...

    @is_enabled.setter
    def is_enabled(self, is_enabled: Optional[bool]) -> None: ...

    @property
    def mapping(self) -> Optional[bool]: ...

    @mapping.setter
    def mapping(self, mapping: Optional[bool]) -> None: ...

    @property
    def mappings(self) -> Optional[IdentityMappingListV1]: ...

    @mappings.setter
    def mappings(self, mappings: Optional[IdentityMappingListV1]) -> None: ...

    @property
    def name(self) -> str: ...

    @name.setter
    def name(self, name: str) -> None: ...

    @property
    def remote_group_editable(self) -> Optional[bool]: ...

    @remote_group_editable.setter
    def remote_group_editable(self, remote_group_editable: Optional[bool]) -> None: ...

    @property
    def remove_permissions(self) -> Optional[bool]: ...

    @remove_permissions.setter
    def remove_permissions(self, remove_permissions: Optional[bool]) -> None: ...

    @property
    def sync_token(self) -> Optional[str]: ...

    @sync_token.setter
    def sync_token(self, sync_token: Optional[str]) -> None: ...

    def to_dict(self) -> Dict[str, Any]: ...
    def to_str(self) -> str: ...
    def __repr__(self) -> str: ...
    def __eq__(self, other: object) -> bool: ...
    def __ne__(self, other: object) -> bool: ...



# coding: utf-8

"""
    Seeq REST API

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: 66.119.1-v202603241138-CD
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from __future__ import annotations

from typing import Any, ClassVar, Dict, List, Optional, Set, TYPE_CHECKING

if TYPE_CHECKING:
    from . import *  # noqa: F401,F403


class AnnotationInterestInputV1(object):
    swagger_types: ClassVar[Dict[str, str]] = ...
    attribute_map: ClassVar[Dict[str, str]] = ...

    _detail_id: Optional[str]
    _interest_id: str
    _search_interval: Optional[TimeInterval]
    _search_interval_end: Optional[int]
    _search_interval_start: Optional[int]


    def __init__(
        self,
        detail_id: Optional[str] = None,
        interest_id: Optional[str] = None,
        search_interval: Optional[TimeInterval] = None,
        search_interval_end: Optional[int] = None,
        search_interval_start: Optional[int] = None,
    ) -> None: ...

    @property
    def detail_id(self) -> Optional[str]: ...

    @detail_id.setter
    def detail_id(self, detail_id: Optional[str]) -> None: ...

    @property
    def interest_id(self) -> str: ...

    @interest_id.setter
    def interest_id(self, interest_id: str) -> None: ...

    @property
    def search_interval(self) -> Optional[TimeInterval]: ...

    @search_interval.setter
    def search_interval(self, search_interval: Optional[TimeInterval]) -> None: ...

    @property
    def search_interval_end(self) -> Optional[int]: ...

    @search_interval_end.setter
    def search_interval_end(self, search_interval_end: Optional[int]) -> None: ...

    @property
    def search_interval_start(self) -> Optional[int]: ...

    @search_interval_start.setter
    def search_interval_start(self, search_interval_start: Optional[int]) -> None: ...

    def to_dict(self) -> Dict[str, Any]: ...
    def to_str(self) -> str: ...
    def __repr__(self) -> str: ...
    def __eq__(self, other: object) -> bool: ...
    def __ne__(self, other: object) -> bool: ...



# coding: utf-8

"""
    Seeq REST API

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: 66.119.1-v202603241138-CD
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from __future__ import annotations

from typing import Any, Dict, List, Optional, Set

from ..api_client import ApiClient
from ..configuration import Configuration
from ..models import *

class TableDefinitionsApi(object):
    api_client: ApiClient

    def __init__(self, api_client: Optional[ApiClient] = None) -> None: ...

    def add_columns_to_table_definition(
        self,
        **kwargs: Any,
    ) -> TableComputeOutputV1: ...

    def add_columns_to_table_definition_with_http_info(
        self,
        **kwargs: Any,
    ) -> Any: ...

    def add_overrides_to_column(
        self,
        **kwargs: Any,
    ) -> TableComputeOutputV1: ...

    def add_overrides_to_column_with_http_info(
        self,
        **kwargs: Any,
    ) -> Any: ...

    def archive_table_definition(
        self,
        **kwargs: Any,
    ) -> ArchiveOutputV1: ...

    def archive_table_definition_with_http_info(
        self,
        **kwargs: Any,
    ) -> Any: ...

    def cleanup(
        self,
        **kwargs: Any,
    ) -> DatasourceCleanUpOutputV1: ...

    def cleanup_with_http_info(
        self,
        **kwargs: Any,
    ) -> Any: ...

    def create_table_definition(
        self,
        **kwargs: Any,
    ) -> TableDefinitionOutputV1: ...

    def create_table_definition_with_http_info(
        self,
        **kwargs: Any,
    ) -> Any: ...

    def create_table_definition_from_csv(
        self,
        **kwargs: Any,
    ) -> TableDefinitionOutputV1: ...

    def create_table_definition_from_csv_with_http_info(
        self,
        **kwargs: Any,
    ) -> Any: ...

    def delete_column_from_table_definition(
        self,
        **kwargs: Any,
    ) -> TableDefinitionOutputV1: ...

    def delete_column_from_table_definition_with_http_info(
        self,
        **kwargs: Any,
    ) -> Any: ...

    def delete_overrides_from_column(
        self,
        **kwargs: Any,
    ) -> TableComputeOutputV1: ...

    def delete_overrides_from_column_with_http_info(
        self,
        **kwargs: Any,
    ) -> Any: ...

    def get_table_definition(
        self,
        **kwargs: Any,
    ) -> TableDefinitionOutputV1: ...

    def get_table_definition_with_http_info(
        self,
        **kwargs: Any,
    ) -> Any: ...

    def get_table_definitions(
        self,
        **kwargs: Any,
    ) -> TableDefinitionOutputListV1: ...

    def get_table_definitions_with_http_info(
        self,
        **kwargs: Any,
    ) -> Any: ...

    def import_table_csv(
        self,
        **kwargs: Any,
    ) -> ImportTableCSVOutputV1: ...

    def import_table_csv_with_http_info(
        self,
        **kwargs: Any,
    ) -> Any: ...

    def modify_column_in_table_definition(
        self,
        **kwargs: Any,
    ) -> TableComputeOutputV1: ...

    def modify_column_in_table_definition_with_http_info(
        self,
        **kwargs: Any,
    ) -> Any: ...

    def modify_columns_in_table_definition(
        self,
        **kwargs: Any,
    ) -> TableComputeOutputV1: ...

    def modify_columns_in_table_definition_with_http_info(
        self,
        **kwargs: Any,
    ) -> Any: ...

    def preview_table_definition(
        self,
        **kwargs: Any,
    ) -> TableDefinitionPreviewOutputV1: ...

    def preview_table_definition_with_http_info(
        self,
        **kwargs: Any,
    ) -> Any: ...

    def publish_rows_from_csv(
        self,
        **kwargs: Any,
    ) -> TableDefinitionCSVPublishRowsOutputV1: ...

    def publish_rows_from_csv_with_http_info(
        self,
        **kwargs: Any,
    ) -> Any: ...

    def recompute_column_in_table_definition(
        self,
        **kwargs: Any,
    ) -> TableComputeOutputV1: ...

    def recompute_column_in_table_definition_with_http_info(
        self,
        **kwargs: Any,
    ) -> Any: ...

    def reorder_columns_in_table_definition(
        self,
        **kwargs: Any,
    ) -> TableDefinitionOutputV1: ...

    def reorder_columns_in_table_definition_with_http_info(
        self,
        **kwargs: Any,
    ) -> Any: ...

    def update_table_definition(
        self,
        **kwargs: Any,
    ) -> TableDefinitionOutputV1: ...

    def update_table_definition_with_http_info(
        self,
        **kwargs: Any,
    ) -> Any: ...

    def update_table_definition_from_csv(
        self,
        **kwargs: Any,
    ) -> TableDefinitionOutputV1: ...

    def update_table_definition_from_csv_with_http_info(
        self,
        **kwargs: Any,
    ) -> Any: ...



# coding: utf-8

"""
    Seeq REST API

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: 66.119.1-v202603241138-CD
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from __future__ import annotations

from typing import Any, ClassVar, Dict, List, Optional, Set, TYPE_CHECKING

if TYPE_CHECKING:
    from . import *  # noqa: F401,F403


class TileUpdateInputV1(object):
    swagger_types: ClassVar[Dict[str, str]] = ...
    attribute_map: ClassVar[Dict[str, str]] = ...

    _background_color: Optional[str]
    _border_color: Optional[str]
    _chart_options: Optional[str]
    _compare_range_end: Optional[str]
    _compare_range_start: Optional[str]
    _data_view_id: Optional[str]
    _date_range_end: Optional[str]
    _date_range_start: Optional[str]
    _decimal_places: Optional[int]
    _grouped_by_key: Optional[str]
    _height: Optional[int]
    _name: Optional[str]
    _prompt: Optional[str]
    _rehydration_instructions: Optional[RehydrationInstructionsInputV1]
    _tolerance: Optional[float]
    _type: Optional[str]
    _unit: Optional[str]
    _value_column: Optional[str]
    _version: Optional[str]
    _width: Optional[int]
    _worksheet_id: Optional[str]
    _x: Optional[int]
    _y: Optional[int]


    def __init__(
        self,
        background_color: Optional[str] = None,
        border_color: Optional[str] = None,
        chart_options: Optional[str] = None,
        compare_range_end: Optional[str] = None,
        compare_range_start: Optional[str] = None,
        data_view_id: Optional[str] = None,
        date_range_end: Optional[str] = None,
        date_range_start: Optional[str] = None,
        decimal_places: Optional[int] = None,
        grouped_by_key: Optional[str] = None,
        height: Optional[int] = None,
        name: Optional[str] = None,
        prompt: Optional[str] = None,
        rehydration_instructions: Optional[RehydrationInstructionsInputV1] = None,
        tolerance: Optional[float] = None,
        type: Optional[str] = None,
        unit: Optional[str] = None,
        value_column: Optional[str] = None,
        version: Optional[str] = None,
        width: Optional[int] = None,
        worksheet_id: Optional[str] = None,
        x: Optional[int] = None,
        y: Optional[int] = None,
    ) -> None: ...

    @property
    def background_color(self) -> Optional[str]: ...

    @background_color.setter
    def background_color(self, background_color: Optional[str]) -> None: ...

    @property
    def border_color(self) -> Optional[str]: ...

    @border_color.setter
    def border_color(self, border_color: Optional[str]) -> None: ...

    @property
    def chart_options(self) -> Optional[str]: ...

    @chart_options.setter
    def chart_options(self, chart_options: Optional[str]) -> None: ...

    @property
    def compare_range_end(self) -> Optional[str]: ...

    @compare_range_end.setter
    def compare_range_end(self, compare_range_end: Optional[str]) -> None: ...

    @property
    def compare_range_start(self) -> Optional[str]: ...

    @compare_range_start.setter
    def compare_range_start(self, compare_range_start: Optional[str]) -> None: ...

    @property
    def data_view_id(self) -> Optional[str]: ...

    @data_view_id.setter
    def data_view_id(self, data_view_id: Optional[str]) -> None: ...

    @property
    def date_range_end(self) -> Optional[str]: ...

    @date_range_end.setter
    def date_range_end(self, date_range_end: Optional[str]) -> None: ...

    @property
    def date_range_start(self) -> Optional[str]: ...

    @date_range_start.setter
    def date_range_start(self, date_range_start: Optional[str]) -> None: ...

    @property
    def decimal_places(self) -> Optional[int]: ...

    @decimal_places.setter
    def decimal_places(self, decimal_places: Optional[int]) -> None: ...

    @property
    def grouped_by_key(self) -> Optional[str]: ...

    @grouped_by_key.setter
    def grouped_by_key(self, grouped_by_key: Optional[str]) -> None: ...

    @property
    def height(self) -> Optional[int]: ...

    @height.setter
    def height(self, height: Optional[int]) -> None: ...

    @property
    def name(self) -> Optional[str]: ...

    @name.setter
    def name(self, name: Optional[str]) -> None: ...

    @property
    def prompt(self) -> Optional[str]: ...

    @prompt.setter
    def prompt(self, prompt: Optional[str]) -> None: ...

    @property
    def rehydration_instructions(self) -> Optional[RehydrationInstructionsInputV1]: ...

    @rehydration_instructions.setter
    def rehydration_instructions(self, rehydration_instructions: Optional[RehydrationInstructionsInputV1]) -> None: ...

    @property
    def tolerance(self) -> Optional[float]: ...

    @tolerance.setter
    def tolerance(self, tolerance: Optional[float]) -> None: ...

    @property
    def type(self) -> Optional[str]: ...

    @type.setter
    def type(self, type: Optional[str]) -> None: ...

    @property
    def unit(self) -> Optional[str]: ...

    @unit.setter
    def unit(self, unit: Optional[str]) -> None: ...

    @property
    def value_column(self) -> Optional[str]: ...

    @value_column.setter
    def value_column(self, value_column: Optional[str]) -> None: ...

    @property
    def version(self) -> Optional[str]: ...

    @version.setter
    def version(self, version: Optional[str]) -> None: ...

    @property
    def width(self) -> Optional[int]: ...

    @width.setter
    def width(self, width: Optional[int]) -> None: ...

    @property
    def worksheet_id(self) -> Optional[str]: ...

    @worksheet_id.setter
    def worksheet_id(self, worksheet_id: Optional[str]) -> None: ...

    @property
    def x(self) -> Optional[int]: ...

    @x.setter
    def x(self, x: Optional[int]) -> None: ...

    @property
    def y(self) -> Optional[int]: ...

    @y.setter
    def y(self, y: Optional[int]) -> None: ...

    def to_dict(self) -> Dict[str, Any]: ...
    def to_str(self) -> str: ...
    def __repr__(self) -> str: ...
    def __eq__(self, other: object) -> bool: ...
    def __ne__(self, other: object) -> bool: ...



# coding: utf-8

"""
    Seeq REST API

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: 66.119.1-v202603241138-CD
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from pprint import pformat
from six import iteritems
import re


class LastRunStateOutputV1(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """


    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'condition_guid': 'str',
        'cursor_key': 'int',
        'earliest_uncertain_end_time_capsule_start': 'int',
        'error_count': 'int',
        'id_property': 'str',
        'last_error': 'str',
        'last_error_time_created': 'int',
        'uncertain_capsule_ids': 'list[str]'
    }

    attribute_map = {
        'condition_guid': 'conditionGuid',
        'cursor_key': 'cursorKey',
        'earliest_uncertain_end_time_capsule_start': 'earliestUncertainEndTimeCapsuleStart',
        'error_count': 'errorCount',
        'id_property': 'idProperty',
        'last_error': 'lastError',
        'last_error_time_created': 'lastErrorTimeCreated',
        'uncertain_capsule_ids': 'uncertainCapsuleIds'
    }

    def __init__(self, condition_guid=None, cursor_key=None, earliest_uncertain_end_time_capsule_start=None, error_count=None, id_property=None, last_error=None, last_error_time_created=None, uncertain_capsule_ids=None):
        """
        LastRunStateOutputV1 - a model defined in Swagger
        """

        self._condition_guid = None
        self._cursor_key = None
        self._earliest_uncertain_end_time_capsule_start = None
        self._error_count = None
        self._id_property = None
        self._last_error = None
        self._last_error_time_created = None
        self._uncertain_capsule_ids = None

        if condition_guid is not None:
          self.condition_guid = condition_guid
        if cursor_key is not None:
          self.cursor_key = cursor_key
        if earliest_uncertain_end_time_capsule_start is not None:
          self.earliest_uncertain_end_time_capsule_start = earliest_uncertain_end_time_capsule_start
        if error_count is not None:
          self.error_count = error_count
        if id_property is not None:
          self.id_property = id_property
        if last_error is not None:
          self.last_error = last_error
        if last_error_time_created is not None:
          self.last_error_time_created = last_error_time_created
        if uncertain_capsule_ids is not None:
          self.uncertain_capsule_ids = uncertain_capsule_ids

    @property
    def condition_guid(self):
        """
        Gets the condition_guid of this LastRunStateOutputV1.
        The ID of the monitored condition

        :return: The condition_guid of this LastRunStateOutputV1.
        :rtype: str
        """
        return self._condition_guid

    @condition_guid.setter
    def condition_guid(self, condition_guid):
        """
        Sets the condition_guid of this LastRunStateOutputV1.
        The ID of the monitored condition

        :param condition_guid: The condition_guid of this LastRunStateOutputV1.
        :type: str
        """
        if condition_guid is None:
            raise ValueError("Invalid value for `condition_guid`, must not be `None`")

        self._condition_guid = condition_guid

    @property
    def cursor_key(self):
        """
        Gets the cursor_key of this LastRunStateOutputV1.
        The cursor key for the last run

        :return: The cursor_key of this LastRunStateOutputV1.
        :rtype: int
        """
        return self._cursor_key

    @cursor_key.setter
    def cursor_key(self, cursor_key):
        """
        Sets the cursor_key of this LastRunStateOutputV1.
        The cursor key for the last run

        :param cursor_key: The cursor_key of this LastRunStateOutputV1.
        :type: int
        """

        self._cursor_key = cursor_key

    @property
    def earliest_uncertain_end_time_capsule_start(self):
        """
        Gets the earliest_uncertain_end_time_capsule_start of this LastRunStateOutputV1.
        The earliest uncertain end time capsule start time found in the last run

        :return: The earliest_uncertain_end_time_capsule_start of this LastRunStateOutputV1.
        :rtype: int
        """
        return self._earliest_uncertain_end_time_capsule_start

    @earliest_uncertain_end_time_capsule_start.setter
    def earliest_uncertain_end_time_capsule_start(self, earliest_uncertain_end_time_capsule_start):
        """
        Sets the earliest_uncertain_end_time_capsule_start of this LastRunStateOutputV1.
        The earliest uncertain end time capsule start time found in the last run

        :param earliest_uncertain_end_time_capsule_start: The earliest_uncertain_end_time_capsule_start of this LastRunStateOutputV1.
        :type: int
        """

        self._earliest_uncertain_end_time_capsule_start = earliest_uncertain_end_time_capsule_start

    @property
    def error_count(self):
        """
        Gets the error_count of this LastRunStateOutputV1.
        The number of errors that have occurred since the last successful run

        :return: The error_count of this LastRunStateOutputV1.
        :rtype: int
        """
        return self._error_count

    @error_count.setter
    def error_count(self, error_count):
        """
        Sets the error_count of this LastRunStateOutputV1.
        The number of errors that have occurred since the last successful run

        :param error_count: The error_count of this LastRunStateOutputV1.
        :type: int
        """

        self._error_count = error_count

    @property
    def id_property(self):
        """
        Gets the id_property of this LastRunStateOutputV1.
        The ID property of the condition, if any

        :return: The id_property of this LastRunStateOutputV1.
        :rtype: str
        """
        return self._id_property

    @id_property.setter
    def id_property(self, id_property):
        """
        Sets the id_property of this LastRunStateOutputV1.
        The ID property of the condition, if any

        :param id_property: The id_property of this LastRunStateOutputV1.
        :type: str
        """

        self._id_property = id_property

    @property
    def last_error(self):
        """
        Gets the last_error of this LastRunStateOutputV1.
        The last error message, if any error occurred during the last run

        :return: The last_error of this LastRunStateOutputV1.
        :rtype: str
        """
        return self._last_error

    @last_error.setter
    def last_error(self, last_error):
        """
        Sets the last_error of this LastRunStateOutputV1.
        The last error message, if any error occurred during the last run

        :param last_error: The last_error of this LastRunStateOutputV1.
        :type: str
        """

        self._last_error = last_error

    @property
    def last_error_time_created(self):
        """
        Gets the last_error_time_created of this LastRunStateOutputV1.
        The time the last error occurred, if any

        :return: The last_error_time_created of this LastRunStateOutputV1.
        :rtype: int
        """
        return self._last_error_time_created

    @last_error_time_created.setter
    def last_error_time_created(self, last_error_time_created):
        """
        Sets the last_error_time_created of this LastRunStateOutputV1.
        The time the last error occurred, if any

        :param last_error_time_created: The last_error_time_created of this LastRunStateOutputV1.
        :type: int
        """

        self._last_error_time_created = last_error_time_created

    @property
    def uncertain_capsule_ids(self):
        """
        Gets the uncertain_capsule_ids of this LastRunStateOutputV1.
        The IDs of the uncertain capsules that were found in the last run

        :return: The uncertain_capsule_ids of this LastRunStateOutputV1.
        :rtype: list[str]
        """
        return self._uncertain_capsule_ids

    @uncertain_capsule_ids.setter
    def uncertain_capsule_ids(self, uncertain_capsule_ids):
        """
        Sets the uncertain_capsule_ids of this LastRunStateOutputV1.
        The IDs of the uncertain capsules that were found in the last run

        :param uncertain_capsule_ids: The uncertain_capsule_ids of this LastRunStateOutputV1.
        :type: list[str]
        """

        self._uncertain_capsule_ids = uncertain_capsule_ids

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        if not isinstance(other, LastRunStateOutputV1):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other



# coding: utf-8

"""
    Seeq REST API

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: 66.119.1-v202603241138-CD
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from pprint import pformat
from six import iteritems
import re


class FeatureRuleV1(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """


    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'boolean_constant': 'ModelBooleanConstantRuleV1',
        'formula_creator': 'ModelFormulaCreatorRuleV1',
        'id': 'str',
        'inputs': 'list[ModelRuleInputV1Object]',
        'numeric_scalar_creator': 'ModelScalarCreatorRuleV1',
        'string_scalar_creator': 'ModelScalarCreatorRuleV1'
    }

    attribute_map = {
        'boolean_constant': 'booleanConstant',
        'formula_creator': 'formulaCreator',
        'id': 'id',
        'inputs': 'inputs',
        'numeric_scalar_creator': 'numericScalarCreator',
        'string_scalar_creator': 'stringScalarCreator'
    }

    def __init__(self, boolean_constant=None, formula_creator=None, id=None, inputs=None, numeric_scalar_creator=None, string_scalar_creator=None):
        """
        FeatureRuleV1 - a model defined in Swagger
        """

        self._boolean_constant = None
        self._formula_creator = None
        self._id = None
        self._inputs = None
        self._numeric_scalar_creator = None
        self._string_scalar_creator = None

        if boolean_constant is not None:
          self.boolean_constant = boolean_constant
        if formula_creator is not None:
          self.formula_creator = formula_creator
        if id is not None:
          self.id = id
        if inputs is not None:
          self.inputs = inputs
        if numeric_scalar_creator is not None:
          self.numeric_scalar_creator = numeric_scalar_creator
        if string_scalar_creator is not None:
          self.string_scalar_creator = string_scalar_creator

    @property
    def boolean_constant(self):
        """
        Gets the boolean_constant of this FeatureRuleV1.

        :return: The boolean_constant of this FeatureRuleV1.
        :rtype: ModelBooleanConstantRuleV1
        """
        return self._boolean_constant

    @boolean_constant.setter
    def boolean_constant(self, boolean_constant):
        """
        Sets the boolean_constant of this FeatureRuleV1.

        :param boolean_constant: The boolean_constant of this FeatureRuleV1.
        :type: ModelBooleanConstantRuleV1
        """

        self._boolean_constant = boolean_constant

    @property
    def formula_creator(self):
        """
        Gets the formula_creator of this FeatureRuleV1.

        :return: The formula_creator of this FeatureRuleV1.
        :rtype: ModelFormulaCreatorRuleV1
        """
        return self._formula_creator

    @formula_creator.setter
    def formula_creator(self, formula_creator):
        """
        Sets the formula_creator of this FeatureRuleV1.

        :param formula_creator: The formula_creator of this FeatureRuleV1.
        :type: ModelFormulaCreatorRuleV1
        """

        self._formula_creator = formula_creator

    @property
    def id(self):
        """
        Gets the id of this FeatureRuleV1.
        Unique identifier for the rule. Only populated on reads.

        :return: The id of this FeatureRuleV1.
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """
        Sets the id of this FeatureRuleV1.
        Unique identifier for the rule. Only populated on reads.

        :param id: The id of this FeatureRuleV1.
        :type: str
        """

        self._id = id

    @property
    def inputs(self):
        """
        Gets the inputs of this FeatureRuleV1.
        List of rule inputs used by the non-null rule.

        :return: The inputs of this FeatureRuleV1.
        :rtype: list[ModelRuleInputV1Object]
        """
        return self._inputs

    @inputs.setter
    def inputs(self, inputs):
        """
        Sets the inputs of this FeatureRuleV1.
        List of rule inputs used by the non-null rule.

        :param inputs: The inputs of this FeatureRuleV1.
        :type: list[ModelRuleInputV1Object]
        """
        if inputs is None:
            raise ValueError("Invalid value for `inputs`, must not be `None`")

        self._inputs = inputs

    @property
    def numeric_scalar_creator(self):
        """
        Gets the numeric_scalar_creator of this FeatureRuleV1.

        :return: The numeric_scalar_creator of this FeatureRuleV1.
        :rtype: ModelScalarCreatorRuleV1
        """
        return self._numeric_scalar_creator

    @numeric_scalar_creator.setter
    def numeric_scalar_creator(self, numeric_scalar_creator):
        """
        Sets the numeric_scalar_creator of this FeatureRuleV1.

        :param numeric_scalar_creator: The numeric_scalar_creator of this FeatureRuleV1.
        :type: ModelScalarCreatorRuleV1
        """

        self._numeric_scalar_creator = numeric_scalar_creator

    @property
    def string_scalar_creator(self):
        """
        Gets the string_scalar_creator of this FeatureRuleV1.

        :return: The string_scalar_creator of this FeatureRuleV1.
        :rtype: ModelScalarCreatorRuleV1
        """
        return self._string_scalar_creator

    @string_scalar_creator.setter
    def string_scalar_creator(self, string_scalar_creator):
        """
        Sets the string_scalar_creator of this FeatureRuleV1.

        :param string_scalar_creator: The string_scalar_creator of this FeatureRuleV1.
        :type: ModelScalarCreatorRuleV1
        """

        self._string_scalar_creator = string_scalar_creator

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        if not isinstance(other, FeatureRuleV1):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other
